function gtCopyCorrectUndistortCondor(~, ~, workingdirectory)
% GTCOPYCORRECTUNDISTORTCONDOR  Handles the parallelisation
%     gtCopyCorrectUndistortCondor(first, last, workingdirectory)
%     -----------------------------------------------------------
%     Version 002 26-11-2011 by LNervo
%       Comments and clean version.
%     Sub-functions:
%[sub]- sfRename
%
%     Version 001 by AKing
%       gtCopy does the business of copying/correcting/undistorting
%       talking to the database to
%       coordinate copying between multiple condor jobs.
%
%       all filenames, directory names, and paths are determined from the
%       parameters file
%
%       first and last are dummy variables - not used by the function.
%
%

disp('THIS IS THE VERSION IN ANDYS MATLAB DIRECTORY')

if isdeployed
    global GT_MATLAB_HOME
    global GT_DB
    load('workspaceGlobal.mat')
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   load and read data from parameters.mat
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
cd(workingdirectory)
parameters=[];
load('parameters.mat');

sourcedir    = parameters.acq.collection_dir;
destdir      = fullfile( parameters.acq.dir, '0_rawdata', parameters.acq.name );
destdir_orig = fullfile( parameters.acq.dir, '0_rawdata', 'Orig' );

%database connect
gtDBConnect('graindb.esrf.fr', 'gtadmin', 'gtadmin', 'graintracking');

filetable=[parameters.acq.name '_filetable'];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   check directories are okay
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ~exist(sourcedir,'dir')
    gtError('Cannot find source directory!')
end
if ~exist(destdir,'dir')
    mkdir(destdir)
end
if ~exist(destdir_orig,'dir')
    mkdir(destdir_orig)
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   has the data already been moved to analysis directory?
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% determine if we need to move the data from the collection directory to the analysis location.
% If sourcedir is "xxx/0_rawdata/Orig", and destinationdir is "xxx/0_rawdata/scanname"
% then data has already been moved (ie sourcedir==destdir_orig)
%
% directory formats are
% either
% /data/id19/graintracking/ ..path.. /scanname/
% or
% /mntdirect/_data_id19_graintracking/ ..path../scanname/
%
% therefore need two tests

% are paths the same?
path1=sourcedir(1:find(sourcedir=='/',1,'last'));
path2=destdir(1:find(destdir=='/',1,'last'));
% what is the source dir name?
source_dirname=sourcedir(find(sourcedir=='/',1,'last')+1:end);

if strcmp(path1,path2) || strcmp(source_dirname, 'Orig')
    move_data_flag=0;
    disp('not moving data - it is already in the analysis location')
else
    move_data_flag=1;
    disp('moving (or copying) data to the analysis location')
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   copying routine
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('Copying raw images...')
counter=0;
% while loop for function timeout when copying is finished
while counter<100
    found=0;

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %   get the list of files to try and copy
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % source directory file list
    sfiles=dir([sourcedir '/*']);
    n=1;
    %go through the source list, remove directories, parameters.mat,
    while n<=length(sfiles)
        sfname=sfiles(n).name;
        sfdir=sfiles(n).isdir;
        if sfdir || strcmp('parameters.mat',sfname)
            sfiles(n)=[];
        else
            n=n+1;
        end
    end

    %sort files by date order to copy in order
    [~,indx] = sort( [sfiles.('datenum')] );

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %   try to copy files
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    for n = 1:length(sfiles)
        sfname = sfiles(indx(n)).name;

        %check if sfname has already been taken by another condor job
        try
            test = mym(sprintf('insert into %s (filename) values ("%s")', filetable, sfname));
        % Andy 18/03/2012 - fixed this: job should not die if try fails,
        % but test should be false
        catch mexc
            gtPrintException(mexc);
            test = false;
        end

        if test %no other job is copying this file, do copy
            disp(['working on ' sfname])

            if isfield(parameters.acq, 'interlaced_turns') && parameters.acq.interlaced_turns>0
                %if using interlaced turns, may need some renaming
                fnamein  = fullfile(sourcedir, sfiles(indx(n)).name);
                newfname = sfRename(sfiles(indx(n)).name); %determine how file should be renamed
                fnameout = fullfile(destdir, newfname);
                fnameout_orig = fullfile(destdir_orig, sfiles(indx(n)).name); %keep original data as collected
            else %standard routine
                fnamein  = fullfile(sourcedir, sfiles(indx(n)).name);
                newfname = 1; %flag to do copy in this case
                fnameout = fullfile(destdir, sfiles(indx(n)).name);
                fnameout_orig = fullfile(destdir_orig, sfiles(indx(n)).name);
            end

            if ~isempty(newfname)
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                fprintf('Copying %s to %s\n',fnamein,fnameout)
                try
                  gtCopy(fnamein, fnameout, fnameout_orig, parameters, move_data_flag);
                  found=1;
                catch mexc
                  if gtCheckExceptionType(mexc, 'EDF:')
                    message = [ 'Skipping badly formed file: "' fnamein ...
                                '" (' mexc.identifier ')'];
                    gtPrintException(mexc, message);
                  else
                    gtPrintException(mexc, 'Error in the code!!');
                    rethrow(mexc)
                  end
                end
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            else
                fprintf('not happy about this filename, skipping...\n')
            end
        end

    end %for loop over the file list, working in date order

    if found==0
        counter=counter+1;
        pause(10) %have a rest, wait before looking again
        disp('sleeping 10, then look again')
    else
        counter=0;
    end
end
disp('Timed out while waited for files to appear... quitting')


%% Sub-functions


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% sfCopy was a single subfunction in several scripts - I have created a
% single gtCopy function to be used in all cases
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    function newname=sfRename(oldname)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % determine how files should be renamed
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        [~, ~, ext] = fileparts(oldname);
        if 1 %old convention
            %description of scheme:
            %for 80 images collected over two turns
            %note this would be nproj=40 in ftomosetup, so be careful!
            %keep parameters.acq.nproj as images/180degrees in final data
            %first turn:
            %ref0000_0000.edf..., name_0_0000.edf, name_0_0001.edf... name_0_0039.edf, ref0000_0040.edf
            %second turn:
            %name_1_0000.edf, name_1_0001.edf... name_1_0039.edf, ref0000_1_0040.edf
            %we want sequentially number filenames and references groups, without the
            %turn indication.
            images_per_turn=(2*parameters.acq.nproj)/(parameters.acq.interlaced_turns+1);

            if strcmp(ext, '.edf') %edf renaming

                if strcmp(oldname(1:4), 'dark') %for darks don't need to change
                    newname = oldname;

                elseif strcmp(oldname(1:3), 'ref') % bad idea to name scans ref*!

                    if length(oldname) == 16 %no added number in the ref name
                        old_number = str2double(oldname((end-7):(end-4)));
                        chief_turn = 0;
                    elseif length(oldname) == 18 % added number in the ref name
                        old_number = str2double(oldname((end-9):(end-6)));
                        chief_turn = str2double(oldname(14));   % changed from 9 to 14 ! WL
                    else
                        warning('gtCopyCorrectUndistortCondor:wrong_renaming', ...
                            'dont recognise the name of this edf! doing nothing...') %don't rename / renumber / overwrite if not sure!
                    end
                    new_number = old_number+(chief_turn*images_per_turn);
                    newname = sprintf('%s%04d.edf', oldname(1:8), new_number); %keep the ref000x_ part of the name

                elseif strcmp(oldname(1:5), 'quali') % equally bad idea to name scans quali*!

                    if length(oldname) == 14 %no added number in the ref name
                        old_number = str2double(oldname((end-7):(end-4)));
                        chief_turn = 0;
                    elseif length(oldname) == 16 % added number in the ref name
                        old_number = str2double(oldname((end-9):(end-6)));
                        chief_turn = str2double(oldname(12));   % changed from 9 to 14 ! WL
                    else
                        warning('gtCopyCorrectUndistortCondor:wrong_renaming', ...
                            'dont recognise the name of this edf! doing nothing...') %don't rename / renumber / overwrite if not sure!
                    end
                    new_number = old_number+(chief_turn*images_per_turn);
                    newname = sprintf('%s%04d.edf', oldname(1:6), new_number); %keep the quali_ part of the name

                    %do this part last because name is *usually* longer than ref name, and
                    %thus falls over for the case of a ref or a dark
                elseif strcmp(oldname(1:length(parameters.acq.name)), parameters.acq.name) %if this is an image
                    chief_turn = str2double(oldname(length(parameters.acq.name)+1));
                    old_number = str2double(oldname((end-7):(end-4)));
                    new_number = old_number+(chief_turn*images_per_turn);
                    newname = sprintf('%s%04d.edf', parameters.acq.name, new_number); %note that in some datasets we exceed 9999 images.

                else
                    warning('gtCopyCorrectUndistortCondor:wrong_renaming', ...
                            'dont recognise the name of this edf! doing nothing...') %don't rename / renumber / overwrite if not sure!
                    newname = [];
                end

            else %not an edf file
                newname = oldname;
            end
        end
    end %end of sfRename

end %end of function
