function gtCopyCorrectUndistortFulls(sourcedir,destinationdir,sensortype,varargin)
% FUNCTION gtCopyCorrectUndistortFulls(sourcedir,destinationdir,sensortype,varargin)
%
% Copies, corrects and undistorts full images online.
% Destination directory should be .../0_rawdata/scanname .
% Sensor types recognized:
%    - Frelon      - no correction applied
%    - Kodak4Mv1   - missing center line interpolated, 0.96 gamma applied
%
% INPUT
%   sourcedir      = full path of source directory
%   destinationdir = full path of destination directory
%
%   varargin{1}    = full path and name of distortion map file
%


if ~exist(sourcedir,'dir')
    gtError('Cannot find source directory!')
end

if ~exist(destinationdir,'dir')
    [s,msg]=mkdir(destinationdir); disp(msg)
    clear s msg
end

if exist('varargin','var')
    filename_distmapF2D=varargin{1};
    distortion=distortion_read(filename_distmapF2D); % distortion map
    disp('Distortion map loaded.')
else
    disp('No undistortion applied')
end

disp('Copying full images...')

copiedfiles=[];
while true
    d=dir([sourcedir '/*']);
    cfiles=dir([destinationdir '/*']);
    for n=1:length(cfiles)
        copiedfiles{n}=cfiles(n).name;
    end
    for n=1:length(d)
        fname=d(n).name;
        if ~any(strcmp(fname,copiedfiles))
            fnamein=[sourcedir '/' fname];
            fnameout=[destinationdir '/' fname];
            fprintf('Copying %s to %s\n',fnamein,fnameout);
            
            if strcmp(fname(end-2:end),'edf')
                im = edf_wait_read(fnamein);
                
                switch lower(cameratype)
                    
                    case 'kodak4mv1'
                        
                        info=edf_info(fnamein);
                        info.ccdmodel='Kodak4Mv1';
                        info.israw='false';
                        %%%info=rmfield(info,{'dim_1','dim_2'}); why???
                        
                        im=[im(1:midline,:); ...
                            mean([im(midline,:);im(midline+1,:)]);...
                            im(midline+1:end-1,:)];
                        im=im.^0.96;
                        
                    case 'frelon'
                        info=edf_info(fnamein);
                        
                    otherwise
                        fprintf('Sensor type: %s',sensortype)
                        gtError('Sensor type is not recognized.')
                end
                
                im_corr=distortion_correct(im,distortion);
                
                edf_write(im_corr,fnameout,info);
            else
                [s,msg]=copyfile(fnamein,fnameout); disp(msg)
                clear s msg
            end
        end
        
    end
    disp('Sleeping')
    pause(5);
    
end

end % of function
