chdir('C:/wolfgang/data/extinction/Risoe_fine');
n=load('spots.log');

for i=1:n

    name=sprintf('rawsino%d.tif',n);
    p=imread(name)';
    p=double(p);
    len=size(p,1);
    name=sprintf('C:/Program Files/ADCIS-AAI/Aphelion/extinction/angle%d.dat',grain);
    [theta,comx]=textread(name,'%s %s %*[^\n]','delimiter',',');
    theta=str2double(theta)/180*pi;

    %interp='linear';
    interp='nearest neighbor';
    N=len;


    img = zeros(N);        % Allocate memory for the image.

% Define the x & y axes for the reconstructed image so that the origin
% (center) is in the spot which RADON would choose.
xax = (1:N)-ceil(N/2);
x = repmat(xax, N, 1);    % x coordinates, the y coordinates are rot90(x)
y = rot90(x);

costheta = cos(theta);
sintheta = sin(theta);
ctrIdx = ceil(len/2);     % index of the center of the projections

% Zero pad the projections to size 1+2*ceil(N/sqrt(2)) if this
% quantity is greater than the length of the projections
imgDiag = 2*ceil(N/sqrt(2))+1;  % largest distance through image.
if size(p,1) < imgDiag
   rz = imgDiag - size(p,1);  % how many rows of zeros
   p = [zeros(ceil(rz/2),size(p,2)); p; zeros(floor(rz/2),size(p,2))];
   ctrIdx = ctrIdx+ceil(rz/2);
end

% Backprojection - vectorized in (x,y), looping over theta
if strcmp(interp, 'nearest neighbor')
   for i=1:length(theta)
      proj = p(:,i);
      t = round(x*costheta(i) + y*sintheta(i));
      img = img + proj(t+ctrIdx);
   end
elseif strcmp(interp, 'linear')
   for i=1:length(theta)
      proj = p(:,i);
      t = x.*costheta(i) + y.*sintheta(i);
      a = floor(t);
      img = img + (t-a).*proj(a+1+ctrIdx) + (a+1-t).*proj(a+ctrIdx);
   end
elseif strcmp(interp, 'spline')
   for i=1:length(theta)
      proj = p(:,i);
      taxis = (1:size(p,1)) - ctrIdx;
      t = x.*costheta(i) + y.*sintheta(i);
      projContrib = interp1(taxis,proj,t(:),'*spline');
      img = img + reshape(projContrib,N,N);
   end
end


name=sprintf('recon%d.tif',n);
mat2gray(img,[0 255]);
imwrite(mat2gray(img,[0 255]),name)
end
%%%
%%%  Sub-Function:  designFilter
%%%

function filt = designFilter(filter, len, d)
% Returns the Fourier Transform of the filter which will be
% used to filter the projections
%
% INPUT ARGS:   filter - either the string specifying the filter
%               len    - the length of the projections
%               d      - the fraction of frequencies below the nyquist
%                        which we want to pass
%
% OUTPUT ARGS:  filt   - the filter to use on the projections


order = max(64,2^nextpow2(2*len));

% First create a ramp filter - go up to the next highest
% power of 2.

filt = 2*( 0:(order/2) )./order;
w = 2*pi*(0:size(filt,2)-1)/order;   % frequency axis up to Nyquist

switch filter
case 'ram-lak'
   % Do nothing
case 'shepp-logan'
   % be careful not to divide by 0:
   filt(2:end) = filt(2:end) .* (sin(w(2:end)/(2*d))./(w(2:end)/(2*d)));
case 'cosine'
   filt(2:end) = filt(2:end) .* cos(w(2:end)/(2*d));
case 'hamming'
   filt(2:end) = filt(2:end) .* (.54 + .46 * cos(w(2:end)/d));
case 'hann'
   filt(2:end) = filt(2:end) .*(1+cos(w(2:end)./d)) / 2;
otherwise
   error('Invalid filter selected.');
end

filt(w>pi*d) = 0;                      % Crop the frequency response
filt = [filt' ; filt(end-1:-1:2)'];    % Symmetry of the filter



