function [plane_normal, hkl] = gtIndexReflections(Theta, Eta, Omega, pars)
%generate the plane_normal vectors, determine the hkl types
%takes all angles in degrees

parameters=[];
if ~exist('pars','var')
    pars=load('parameters.mat');
    parameters=pars.parameters;
else
    parameters=pars;
end

%convert to radians for calculation
Omega = Omega*pi/180;
Theta = Theta*pi/180;
Eta = Eta*pi/180;

%~~~~~~~~calculate plane normals in sample coordinates~~~~~~~~~~~~
for i=1:length(Omega);
  plane_normal(i,1) = -sin(Theta(i))*cos(Omega(i)) - cos(Theta(i))*sin(Eta(i))*sin(Omega(i));
  plane_normal(i,2) = cos(Theta(i))*sin(Eta(i))*cos(Omega(i)) - sin(Theta(i))*sin(Omega(i));%30/10 - signs change in this line
  plane_normal(i,3) = cos(Theta(i))*cos(Eta(i));
end


%~~~~~~~~~~index reflections~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%determine which Theta is which hkl
% modif sabine
% hkl=zeros(length(Theta),3);
% fin modif sabine
hkl_list=zeros(length(Theta),1);%tmp = 1 means hkl = {111}, 2 means {002} etc

twotheta=parameters.cryst.twoth;
allowed_Theta = (twotheta/2)*pi/180;

dif = abs(repmat(Theta',1,length(allowed_Theta)) - repmat(allowed_Theta,length(Theta),1));
[min_dif,hkl_list]=min(dif,[],2);

%check line is within 5% of prediction
for i=1:length(hkl_list)
    if min_dif(i)/allowed_Theta(hkl_list(i))>0.05
        hkl_list(i)=0;
    end
end


%old system, can produce ambiguous results for closely spaced lines

%allowed_Theta = [0.95*allowed_Theta; 1.05*allowed_Theta];% %5 tolerance

%for i=1:length(allowed_Theta)% run through the allow thetas calculated above
%  dummy = find(Theta>allowed_Theta(1,i) & Theta<allowed_Theta(2,i));
%  hkl_list(dummy)=i;
%end



%this is dangerous, because the list here must in the in same order as the
%list in parameters.  Therefore, if possible get the list of
%reflections
hkl_table=parameters.cryst.hklsp;
hkl=zeros(length(Theta), size(hkl_table,2));





% switch parameters.cryst.spacegroup
%   case 225 % if FCC
%     %hkl lookup table... for FCC
%     % modif sabine
%     hkl=zeros(length(Theta),3);
%     % fin modif sabine
%     hkl_table = [1 1 1 ; 0 0 2 ; 2 2 0 ; 3 1 1 ; 0 0 4 ; 3 3 1];
%   case 229 % if BCC
%           % modif sabine
%     hkl=zeros(length(Theta),3);
%     % fin modif sabine
%     hkl_table = [1 1 0; 0 0 2; 1 1 2];
%     % sabine
%   case 663
%           % modif sabine
%     hkl=zeros(length(Theta),4);
%     % fin modif sabine
%     hkl_table = [...
%             0 0 0 2; ...
%             1 1 -2 0; ...
%             1 -1 0 0; ...
%             1 -1 0 1; ...
%             1 1 -2 2; ...
%             -2 0 2 1; ...
%             ]; 
%         
%     % sabine
%   otherwise
%     disp('sorry, FCC or BCC only for the mo!')
% end%fill in hkl matrix



for i=1:size(hkl_table,1)
  dummy = find(hkl_list == i);
  for d=1:length(dummy)
    hkl(dummy(d),:) = hkl_table(i,:);
  end
end
  
