function [stack,sino,z_of_sino,index] = gtReadSpots_360(spot_id, struct_ids, replaced, parameters)
% function [stack,sino,z_of_sino]=gtReadSpots_360(spot_id, struct_ids, replaced, parameters)

% produce sinogram of all spots in struct_ids vector at the mid-height
% of the seed spot (spot_id).
%replaced: 0=use extspots, 1=replace all with difspots (like WriteStack_replaced)
%_360 for single 360dgree scan convention

%360degree scan convention - ak 10/2007

if isempty(parameters)
  load('parameters.mat');;
end

index=ones(length(struct_ids),1);
stack=zeros(parameters.acq.bb(4),parameters.acq.bb(3),length(struct_ids));
name=parameters.acq.name;

%get the z position for the sinogram
z_of_sino = mym(sprintf(...
  'select ceil(Yorigin + (Ysize/2)) from %sbb inner join %sbboxes on %sbb.bbID = %sbboxes.bboxID where %sbb.extspotID = %d',...
  name,name,name,name,name,...
  spot_id));

Omega = (180/pi)*gtGetOmega(struct_ids, parameters);%convert to degrees

%read images to produce sinogram at position z_of_sino
for i=1:length(struct_ids)
  
  if ~replaced
  try
	
	[BoundingBox(1),BoundingBox(2)] = mym(sprintf('select Xorigin,Yorigin from %sbb inner join %sbboxes on %sbb.bbID=%sbboxes.bboxID where %sbb.extspotID = %d',...
    name,name,name,name,name,...
    struct_ids(i)));
  
    im = gtGetSummedExtSpot_360(struct_ids(i), parameters ,1);% - 1 - already connected
    %warning('bodge - change zero origin bounding boxes in gtReadSpots - fix in autofind')
    if BoundingBox(1)==0
	  BoundingBox(1)=1;
	end
	if BoundingBox(2)==0
	  BoundingBox(2)=1;
	end
  
	%place in stack
	stack(:,:,i) = gtPlaceSubImage(im, zeros(parameters.acq.bb(4), parameters.acq.bb(3)),ceil(BoundingBox(1)), ceil(BoundingBox(2)));
	%scaling
	stack(:,:,i)= 100*stack(:,:,i)/sum(sum(stack(:,:,i)));  % think about some proper scaling here !
  catch
	disp(sprintf('no extspot information for difspot %d - stack will have an empty image',struct_ids(i)));
	disp('setting corresponding index to 0');
	index(i)=0;
  end
  
	
  else %if replacing extspots with difspots
  
    BoundingBox=gtGetBBProps(struct_ids(i), parameters, 1);
    im = gtGetSummedDifSpot(struct_ids(i), parameters, 1);
    %warning('bodge - change zero origin bounding boxes in gtReadSpots - fix in autofind')
	if BoundingBox(1)==0
	  BoundingBox(1)=1;
	end
	if BoundingBox(2)==0
	  BoundingBox(2)=1;
	end
  
	%place in stack
	stack(:,:,i) = gtPlaceSubImage(im, zeros(parameters.acq.bb(4), parameters.acq.bb(3)),ceil(BoundingBox(1)), ceil(BoundingBox(2)));
	%scaling
	stack(:,:,i)= 100*stack(:,:,i)/sum(sum(stack(:,:,i)));  % think about some proper scaling here !
  
  end
  
  %read sino from stack
  sino(:,i) = stack(z_of_sino, :, i);
  
 
end

end
