function volseg = gtChangeThreshold(first, last, ~, iteration, apply_mask, ...
                                    do_morph_recon, percentile1, percentile2, ...
                                    show_results, save_flag)
% GTCHANGETHRESHOLD

load('parameters.mat');

if isdeployed()
    first           = str2double(first);
    last            = str2double(last);
    iteration       = str2double(iteration);
    apply_mask      = str2double(apply_mask);
    do_morph_recon  = str2double(do_morph_recon);
    percentile1     = str2double(percentile1);
    percentile2     = str2double(percentile2);
    show_results    = str2double(show_results);
    save_flag       = str2double(save_flag);
end

for ii = first:last
    fprintf('doing grain %d\n', ii);

    grain_dir = fullfile(parameters.acq.dir, '4_grains', sprintf('grain%d_', ii));
    cd( grain_dir );

    name = sprintf('proj_res0_%d', iteration);
    name2 = sprintf('proj_res0_%d.sdt', iteration);
    if ~exist(name2, 'file')
        unix(sprintf('seg2view %s', name));
    end
    vol = sdt_read(name);
    vol = flipdim(vol,2);  % to be consistent:  i,j,k == X,Y,Z

    if apply_mask
        volbw = sdt_read('difbw_res0_1');
        volbw = flipdim(volbw, 2);

        center = round(size(volbw)/2);

        grayval = volbw(center(1), center(2), center(3));

        volbwtr = volbw > (percentile1/100*grayval);
        marker = false(size(volbw));
        marker(center(1), center(2), center(3)) = true;

        if do_morph_recon
            try
                volbwtr = imreconstruct(marker, volbwtr);
            catch Mexc
                message = ['generation of mask volume failed for this grain' ...
                           ' - proceeding without'];
                gtPrintException(Mexc, message);
            end
        end

        test = vol.*volbwtr;

        volseg = gtThresholdGrain3D(test, percentile2);
    else
        volseg = gtThresholdGrain3D(vol, percentile2);
    end

    if show_results
        GtVolView(vol, 'linkname', 'output');
        GtVolView(volseg, 'linkname', 'output');
        if apply_mask
            GtVolView(volbw, 'linkname', 'output');
            GtVolView(volbwtr, 'linkname', 'output');
        end
    end

    if save_flag
        edf_write(volseg, 'grain.edf', 'float32');
    end

    cd(parameters.acq.dir);
end
