function gtReconstructionManager_3D(grainid, autoselect)
%GUI to choose art params, select and replace reflections, and fix bounding
%boxes...
%like gtnew_new_choose_art...  but better!

%loop through a series of grains

%don't worry about pair_vectors
%360 degree concept

    parameters=[];
    load('parameters.mat');
    gtDBConnect();

    block='on'; %don't return the command line until the user is finished
    overlay=0;

    % modif for Peter K.
    if ~exist('autoselect','var')
        autoselect = false;
    end

    %%%%%%%%%%%%%%%%%
    %remove bad projections automatically
    % do this before starting the manager, so index information is up to date
    if autoselect
        try %licence check
            gt_select_projections_auto(grainid)
            pause(1)
            close; close;
        catch Mexc
            gtPrintException(Mexc, 'no optimisation licence available')
        end
    else
        disp('auto selection of projections disabled')
    end
    %%%%%%%%%%%%%%%%%

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %read in data, sort for convinience
    g=load(sprintf('4_grains/grain%d_/grain%d_.mat',grainid,grainid));
    difspots=g.difspots;

    if isfield(g, 'bad') && g.bad>=1
        fprintf('grain %d is already set to bad=%d\n',grainid, g.bad)
        return
    end

    if isfield(g, 'done') && g.done==1
        check=inputwdefault(sprintf('grain %d already been done! Do you want to proceed anyway? [y/n]',grainid), 'n');
        if check=='n'
            return
        end
    end


    %if it doesn't already exist, add an index, replaced
    if isfield(g, 'index')
        index=g.index;
    else
        index = ones(1,length(difspots));
    end
    if isfield(g, 'replaced')
        replaced=g.replaced;
    else
        replaced = zeros(1,length(difspots));
    end
    if isfield(g, 'bad')
        bad=g.bad;
    else
        bad=0;
    end

    %Estimation of the art parameters still needs to be done

    if length(difspots)>45
        lambda = [1 0.9 0.8];
    elseif length(difspots)>30
        %lambda = [0.3 0.2 0.1]; %initial values
        lambda = [1 0.9 0.8]; %initial values - sheared difspots
    elseif length(difspots)>15
        %lambda = [0.5 0.3 0.1]; %initial values
        lambda = [1 0.9 0.8]; %initial values - sheared difspots
    else
        %lambda = [0.7 0.3 0.2]; %initial values
        lambda = [1 0.9 0.8]; %initial values - sheared difspots
    end

    %unpacking...
    omega=g.omega;theta=g.theta;eta=g.eta;
    %plane_normal=g.plane_normal;hkl=g.hkl;
    stack=squeeze(g.difstack);
    %for editable ART bounding box
    x1 = g.x1;
    y1 = g.y1;
    nx = g.nx;
    ny = g.ny;



    % write spots in ascending omega order, if not already done
    [g.omega,tmp]=sort(g.omega);

    if ~all(tmp==[1:length(tmp)]')

        %if we need to, sort other fields
        omega=g.omega;
        theta = g.theta(tmp);
        eta = g.eta(tmp);
        difspots = g.difspots(tmp);
        %plane_normal = plane_normal(tmp,:);
        %hkl = hkl(tmp,:);
        stack = stack(:,:,tmp);
        index = index(tmp);
        replaced = replaced(tmp);
        id=grainid;
        dir=sprintf('4_grains/grain%d_/',id);
        cd(dir)
        gtChangeProjectionNumbers3D(tmp);
        cd ../../;
        tmp=[1:length(tmp)];
        name=sprintf('4_grains/grain%d_/grain%d_.mat',grainid,grainid);
        save(name,'difspots','stack','theta','eta','omega',...
            'index','replaced','bad','tmp','-append');
        g=load(name);
    else
        disp('no renumbering required');
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Now the interactive part
    refresh=1;

    app.quit=0;

    %setup the figures

    scrsz = get(0,'ScreenSize');

    fig_handle=figure;
    set(fig_handle, 'Position',[50 150 0.75*scrsz(3) .75*scrsz(4)]);
    set(fig_handle,'Renderer','OpenGL');
    StackAxes=subplot(1,3,1);%stack image

    app.stack_slider=uicontrol('style', 'slider');
    set(app.stack_slider, 'callback', @sfSliderFunction)
    set(fig_handle,'windowbuttonmotionfcn',@sfSliderFunction)
    set(fig_handle,'windowbuttondownfcn',@sfTestFunction) %@sfSliderFunction)
    set(fig_handle,'windowbuttonupfcn',@sfSliderFunction)

    set(app.stack_slider,'units','normalized');
    set(app.stack_slider,'position',[0 0 .4 0.05])
    set(app.stack_slider,'min',1,'max',size(stack,3),'sliderstep',[1/size(stack,3) 1/size(stack,3)]);
    set(app.stack_slider,'value',1);
    imshow(stack(:,:,1), [])
    app.currentImage=1;


    BackproAxes=subplot(1,3,2);%crude backpro image
    %set(fig_handle, 'windowbuttondownfcn', @sfDragBBFunction1)
    %set(fig_handle, 'windowbuttonupfcn', @sfDragBBFunction2)
    %set(BackproAxes, 'ButtonDownFcn', @sfDragBBFunction1)
    title('click to change ART bb')

    buttongroup=uibuttongroup('Position', [.4 0 .6 .05]);

    UseButton=uicontrol(buttongroup, 'Style', 'pushbutton', 'string', 'use', 'position', [0 0 50 20]);
    set(UseButton, 'callback', @sfUseButtonFunction)

    UseAllButton=uicontrol(buttongroup, 'Style', 'pushbutton', 'string', 'use all', 'position', [50 0 50 20]);
    set(UseAllButton, 'callback', @sfUseAllButtonFunction)

%   ReplaceButton=uicontrol(buttongroup, 'Style', 'pushbutton', 'string', 'replace', 'position', [100 0 50 20]);
%   set(ReplaceButton, 'callback', @sfReplaceButtonFunction)

%   ReplaceAllButton=uicontrol(buttongroup, 'Style', 'pushbutton', 'string', 'replace all', 'position', [150 0 80 20]);
%   set(ReplaceAllButton, 'callback', @sfReplaceAllButtonFunction)

    ARTButton=uicontrol(buttongroup, 'Style', 'pushbutton', 'string', 'Do ART', 'position', [230 0 50 20]);
    set(ARTButton, 'callback', @sfARTButtonFunction)

    lambdastring=[];
    for i=1:length(lambda);
        lambdastring=[lambdastring,num2str(lambda(i)),' '];
    end

    LambdaBox=uicontrol(buttongroup, 'Style', 'edit', 'String', lambdastring, 'position', [280 0 70 20]);

    BadButton=uicontrol(buttongroup, 'Style', 'pushbutton', 'string', 'bad grain', 'position', [350 0 50 20]);
    set(BadButton, 'callback', @sfBadButtonFunction)
    AcceptButton=uicontrol(buttongroup, 'Style', 'pushbutton', 'string', 'ACCEPT!', 'position', [400 0 50 20]);
    set(AcceptButton, 'callback', @sfAcceptButtonFunction)


    %add a button to escape without making changes
    exitbuttongroup=uibuttongroup('Position', [.85 .95 .15 .05]);
    ExitButton=uicontrol(exitbuttongroup, 'Style', 'pushbutton', 'string', 'quit, no changes', 'position', [0 0 100 20]);
    set(ExitButton, 'callback', @sfExitButtonFunction)



    %make overlays for backproim, prepare a big image to show in the left
    %hand window
    %get max size(stack,1) of spots

    big_image=zeros((size(stack,1)*(size(stack,3)+6)), size(stack,2)); %pad by three images top and bottom
    app.overlays=zeros(parameters.acq.bb(3), parameters.acq.bb(3), size(stack,3));

    for i=1:size(stack,3)
        %sino(:,i) = stack(g.zcenter, :, i)';
        big_image((i+2)*size(stack,1)+1:(i+3)*size(stack,1), :) =  stack(:,:,i);
    end

    % backprojection of individual spots
    if overlay
        for i=1:size(stack,3)
            size(stack);
            disp(sprintf('3D backprojection of proj%d',i));
            g.index=zeros(size(stack,3),1);
            g.index(i)=1;
            tmp=backpro_3D(parameters,g);
            overlays(:,:,i)=tmp(:,:,2);
            %app.centroidx(i) = sino(:,i)'*(1:size(sino,1))'/sum(sino(:,i));
        end
    end

    g.index=index;

    tmp=backpro_3D(parameters,g);
    app.BPimage=tmp(:,:,2);



    ARTAxes=subplot(1,3,3);
    sfSliderFunction
    sfARTButtonFunction %first "press" of the button

    if strcmp(block,'on')
        % if user wants nothing to return until findshift is finished
        while 1
            drawnow
            if app.quit==1
                break
            end
        end
    end


    function sfTestFunction(varargin)%which subfunction should the button down go to?
        if isequal(gco,app.stack_slider)
            sfSliderFunction
        elseif isequal(gca,BackproAxes)
            sfDragBBFunction1
        end
    end

    function sfSliderFunction(varargin)
        if (isequal(gco,app.stack_slider) || refresh)
            tmp=round(get(app.stack_slider,'value'));
            if (tmp~=app.currentImage || refresh)

                subplot(1,3,1)% update stack figure
                hold off
                app.currentImage=tmp;
                %get 7 image subsection of big_image
                im_start=((app.currentImage-1)*size(stack,1))+1;
                im_end=(app.currentImage+6)*size(stack,1);

                imshow(big_image(im_start:im_end, :), [])
                hold on
                %highlight current image
                xdata=[1 size(big_image,2) size(big_image, 2) 1 1];
                ydata=[(3*size(stack,1))+1 (3*size(stack,1))+1 4*size(stack,1) 4*size(stack,1) (3*size(stack,1))+1];
                %adjust line colour according to index

                if index(app.currentImage)==1 %if using, green
                    plot(xdata, ydata, 'g');
                else %if not using, red
                    plot(xdata, ydata, 'r');
                end

                title(sprintf('id: %d, use: %d, replaced: %d', difspots(app.currentImage), index(app.currentImage), replaced(app.currentImage)))
                drawnow

                subplot(1,3,2)% update backpro image overlay
                hold off
                imshow(app.BPimage, []); %show the first backprojection
                %colormap jet
                hold on
                title('click to change ART bb')

                if overlay %if alpha thing is working?
                    app.BPoverlay=zeros([size(app.BPimage) 3]);
                    %adjust overlay colour according to index
                    if index(app.currentImage)==1 %if using, green
                        app.BPoverlay(:,:,2)=app.overlays(:,:,app.currentImage);
                    else %if not using, red
                        app.BPoverlay(:,:,1)=app.overlays(:,:,app.currentImage);
                    end
                    app.BPoverlay=image(app.BPoverlay, 'XData', [1:size(app.BPimage,2)], 'YData', [1:size(app.BPimage,1)]);
                    set(app.BPoverlay, 'AlphaData', 0.04*ones(size(app.BPimage)))

                    %%%%%%%%  alternative display mode if alpha overlay isn't working
                else %plot a simple line over the current projection

                    %spot_com=app.centroidx(app.currentImage);
                    spot_omega=omega(app.currentImage)*pi/180; %omega in degreees
                    %experiment parameters
                    %centre_of_backproimg_x = parameters.acq.bb(3)/2;
                    %centre_of_backproimg_y = parameters.acq.bb(3)/2;
                    %point=[centre_of_backproimg_x, centre_of_backproimg_y];
                    %make line parameters
                    grad=tan(spot_omega);
                    %dist of com line from centre
                    %offset_com=spot_com-parameters.acq.bb(3)/2;
                    %centre point of line though the projection
                    %point=point+(offset_com*[cos(spot_omega) -sin(spot_omega)]);
                    [point(1), point(2), point(3)]=gtTrLabToSamBB(g.center(1), g.center(2),g.center(3),parameters);
                    %put into format y = mx + c
                    m = grad;
                    c = point(2) - (m*point(1));
                    ez_line=ezplot(sprintf('%f*y + %f - x = 0',m,c),[1 parameters.acq.bb(3)]);

                    if index(app.currentImage)==1 %if using, green
                        set(ez_line,'color','g');
                    else %if not using, red
                        set(ez_line, 'color', 'r');
                    end

                end



                refresh=0;
            end
        end
    end

%drag out a new bounding box
    function sfDragBBFunction1(varargin)
        %      point1 = get(BackproAxes,'CurrentPoint'); % button down detected
        %point1=point1(1, 1:2)
        %       pointx=point1(1, 1);
        %       pointy=point1(1, 2);
        %       if pointx>0 && pointx<size(app.BPimage,2) && pointy>0 && pointy<size(app.BPimage,2) %if point within image
        %           app.newx1=ceil(pointx);
        %           app.newy1=ceil(pointy);
        %       end
        p1 = get(BackproAxes,'CurrentPoint');
        p1=p1(1, 1:2);
        bbox=rbbox;
        p2 = get(BackproAxes,'CurrentPoint');
        p2=p2(1, 1:2);
        point1=min(p1, p2);
        offset=abs(p1-p2);

        pointx1=point1(1);
        pointy1=point1(2);
        pointx2=point1(1)+offset(1);
        pointy2=point1(2)+offset(2);
        points=[pointx1 pointy1 pointx2 pointy2];


        if all(points>-10 && points<size(app.BPimage,2)+10) %if both points ~within image
            %correct if point is slightly outside image
            if pointx1<1
                pointx1=1;
            end
            if pointy1<1
                pointy1=1;
            end
            if pointx2>size(app.BPimage,2)
                pointx2=size(app.BPimage,2);
            end
            if pointy2>size(app.BPimage,2)
                pointy2=size(app.BPimage,2);
            end
            x1=ceil(pointx1);
            y1=ceil(pointy1);
            nx=ceil(pointx2-x1);
            ny=ceil(pointy2-y1);
            save(sprintf('4_grains/grain%d_/grain%d_.mat',grainid,grainid),'x1', 'y1', 'nx', 'ny', '-append');
            sfARTButtonFunction %rerun ART
        end

    end


%%%sf to use/not use a projection
    function sfUseButtonFunction(~, ~)
        index(app.currentImage)=~index(app.currentImage);
        g.index=index;
        save(sprintf('4_grains/grain%d_/grain%d_.mat',grainid,grainid),'index','-append');
        %redo the backprojection
        app.BPimage=backpro_3D(parameters,g);
        refresh=1;% update the backpro figure
        sfSliderFunction;
    end


%%%sf to use/not use all projections
    function sfUseAllButtonFunction(~, ~)
        if all(index==1)
            index=zeros(size(index));
        else
            index=ones(size(index));
        end
        save(sprintf('4_grains/grain%d_/grain%d_.mat',grainid,grainid),'index','-append');
        %redo the backprojection
        g.index=index;
        app.BPimage=backpro_3D(parameters,g);
        refresh=1;% update the backpro figure
        sfSliderFunction;
    end

%%subfunction for doing ART on a central section of the grain to test
%%parameters
    function sfARTButtonFunction(varargin)
        %first read the string in LambdaBox
        lambdastringnew=get(LambdaBox, 'String');
        lambdastringnew=['[ ' lambdastringnew ' ]'];
        lambdanew=str2num(lambdastringnew);
        %if length(lambdanew)==3
        lambda=lambdanew;
        save(sprintf('4_grains/grain%d_/grain%d_.mat',grainid,grainid),'lambda','-append');
        %end

        z1 = round(g.center(3))-1;
        nz_sub = 3; %do 5 slices (more representative)

        im=gtMakeARTJob3D('proj','test.par',find(g.index),[],g,parameters,lambda,length(find(g.index)),g.x1,g.nx,g.y1,g.ny,z1,nz_sub,1,0);

        app.ARTimage = im(:,:,ceil(nz_sub/2));%collect middle slice

        subplot(1,3,3)
        imshow(app.ARTimage, [])
        title('ART output')
    end

    function sfBadButtonFunction(varargin)
        bad=1;
        done=1;
        save(sprintf('4_grains/grain%d_/grain%d_.mat',grainid,grainid),'bad', 'done','-append');
        app.quit=1;
        done=0;
        close
    end

    function sfAcceptButtonFunction(varargin)
        %launch full ART reconstruction
        done=1;
        save(sprintf('4_grains/grain%d_/grain%d_.mat',grainid,grainid), 'stack', 'done','-append');
        done=0;
        gtDoART(grainid);
        app.quit=1;
        close
    end

    function sfExitButtonFunction(varargin)
        %finish without changes
        done=1;
        app.quit=1;
        close
    end
end

