function im5 = threshold_grain_auto(grainid);

%argument is the grain ID (the number of the grain folder)
%im is the greyscale, reconstructed grain, which can be read in from
%the .sdt file
%auto - remove interaction, make a bit more clever to compensate
%sets threshold by statistics,
%dilates and erodes to fill holes using an estimation of how hollow the
%grain is.  erodes and dilate to remove spurs, but by a fixed SE=ones(6,6,6)


%load data
parameters=[];
if isempty(parameters)
  load('parameters.mat');
end

im = sdt_read(sprintf('4_grains/grain%d_/grain%d__res0_3',grainid,grainid));
grain_data = load(sprintf('4_grains/grain%d_/grain%d_.mat',grainid,grainid));%load the grain.mat
      
%find threshold automatically
thresh_val = std(im(find(im~=0)));%std dev, ignoring zeros  
im2=im>thresh_val;

%label routine to remove disconnected bits
im2=bwlabeln(im2,26);
mode_val = mode(im2(find(im2>0)));
im2 = (im2==mode_val);

%how hollow is the grain? - estimate how much dilate/erode is needed
%estimate tight bounding box of the grain
total = sum(im2(:));%total white voxels
%use 1,2,3 as follows.  convert to x,y,z after
[size1,size2,size3]=size(im2);

tmp = sum(im2,3);
tmp1 = sum(tmp,2);%find range in 1
thresh=0.1*mean(tmp1(find(tmp1~=0)));
dummy = find(tmp1>thresh);
min1=min(dummy);
max1=max(dummy);
dummy = find(tmp1>0);
min1_0=min(dummy);
max1_0=max(dummy);


tmp1 = sum(tmp,1);%find range in 2
thresh=0.1*mean(tmp1(find(tmp1~=0)));
dummy = find(tmp1>thresh);
min2=min(dummy);
max2=max(dummy);
dummy = find(tmp1>0);
min2_0=min(dummy);
max2_0=max(dummy);

tmp = sum(im2,1);%find range in 3 (z)
tmp = reshape(tmp,size(im2,2),size(im2,3));
tmp1 = sum(tmp,1);
thresh=0.1*mean(tmp1(find(tmp1~=0)));
dummy = find(tmp1>thresh);
min3=min(dummy);
max3=max(dummy);
dummy = find(tmp1>0);
min3_0=min(dummy);
max3_0=max(dummy);

tight_vol = im2(min1:max1,min2:max2,min3:max3);
loose_vol = im2(min1_0:max1_0,min2_0:max2_0,min3_0:max3_0);

%estimate how solid this grain is.  Take "core samples" along each
%direction
[size1,size2,size3]=size(tight_vol);
core1 = tight_vol(:,ceil(3*size2/8):ceil(5*size2/8),ceil(3*size3/8):ceil(5*size3/8));
count = length(find(core1==1));
total = count + length(find(core1==0));
frac1 = count/total;

core2 = tight_vol(ceil(3*size1/8):ceil(5*size1/8),:,ceil(3*size3/8):ceil(5*size3/8));
count = length(find(core2==1));
total = count + length(find(core2==0));
frac2 = count/total;

core3 = tight_vol(ceil(3*size1/8):ceil(5*size1/8),ceil(3*size2/8):ceil(5*size2/8),:);
count = length(find(core3==1));
total = count + length(find(core3==0));
frac3 = count/total;

frac = mean([frac1,frac2,frac3]);
dilate_length = round((1-frac) * 0.5 * mean([size1,size2,size3]));
disp('factor 0.5 in dilate length to reduce shape change!!')


%pad loose vol with the dilate length so doesn't touch sides
[fullsize1,fullsize2,fullsize3]=size(loose_vol);
loose_vol_padded = zeros([size(loose_vol)]+2*(dilate_length+1));
loose_vol_padded([1:fullsize1]+dilate_length+1, [1:fullsize2]+dilate_length+1, [1:fullsize3]+dilate_length+1)=loose_vol;
original_size=size(loose_vol_padded)

%adjustable decimation to go faster, based on size of loose_vol_padded:
decimate = 2  
if (fullsize1*fullsize2*fullsize3)>1000000
  decimate = 3
elseif (fullsize1*fullsize2*fullsize3)>6000000
  decimate = 4
end

do_scale_and_fill = 1
if do_scale_and_fill %do the dilate erode to fill holes
%down sample - by factor "decimate", 
loose_vol_sampled = loose_vol_padded(1:decimate:end,1:decimate:end,1:decimate:end);
dilate_length_sampled = dilate_length/decimate
sampled_size=size(loose_vol_sampled)

%SE = strel('ball',round(dilate_length_sampled/2),round(dilate_length_sampled),0);
centre=ceil(dilate_length_sampled/2)+1;
[x,y,z]=meshgrid(1:(centre*2)-1,1:(centre*2)-1,1:(centre*2)-1);
distance=sqrt((x-centre).^2+(y-centre).^2+(z-centre).^2);
SE=distance<centre;

tic
% dilate / erode / fill holes routine
im3sampled=imdilate(loose_vol_sampled,SE);
im4sampled=imerode(im3sampled,SE);
im4sampled=imfill(im4sampled,'holes');
toc


%erode / dilate to remove spurs
erodeSE=ones(3,3,3);
im4sampled=imerode(im4sampled,erodeSE);
im4sampled=imdilate(im4sampled,erodeSE);

%scale up by factor decimate
[size1,size2,size3]=size(im4sampled);
[grid1,grid2,grid3]=meshgrid(1:(1/decimate):size2,1:(1/decimate):size1,1:(1/decimate):size3);
im4 = interpn(im4sampled,grid2,grid1,grid3);
new_size=size(im4)
im5 = im4 > 0.5;

%label routine to remove disconnected bits
im5=bwlabeln(im5,26);
mode_val = mode(im5(find(im5>0)));
im5 = (im5==mode_val);

else%if not eroding, dilating
  
%erodeSE=ones(6,6,6);
%im5=imerode(loose_vol_padded,erodeSE);
%im5=imdilate(im5,erodeSE);
im5=loose_vol_padded;
end


%get the correct origin to place in sample
%initial origin, size:
%when pasting old (.sdt) vol into volume, reverse x1,y1 and nx,ny
x_origin = grain_data.x1;
y_origin = grain_data.y1;
z_origin = grain_data.zstart;
vol_x_origin = x_origin + min2_0 - (dilate_length+1);
vol_y_origin = y_origin + min1_0 - (dilate_length+1);
vol_z_origin = z_origin + min3_0 - (dilate_length+1);
[vol_y_size,vol_x_size,vol_z_size]=size(im5);



if 1
%write a new volume
name=sprintf('4_grains/grain%d_/grain%d_2.edf',grainid,grainid);
disp(sprintf('writing volume %s',name));
edf_write(im5,name,'uint8');

%add new info to .mat (how to paste .vol into sample volume)
save(sprintf('4_grains/grain%d_/grain%d_.mat',grainid,grainid),'vol_x_origin','vol_y_origin','vol_z_origin',...
  'vol_x_size','vol_x_size','vol_y_size','vol_z_size','-append');

end