function abs = gtAstraAbsorptionVolume(parameters)
% GTASTRAABSORPTIONVOLUME reconstruct absorption volume using 3D SIRT or 2D FBP
%     abs = gtAstraAbsorptionVolume(parameters)
%     -----------------------------------------
%     Checks if absorption_stack.mat exists (will create it otherwise)
%     Checks if absorption_mask.mat exists (will create it otherwise)
%     Outputs reconstructed volume into file absorption.mat
%
%     parameters.rec.method : '3DART' / '2DFBP'
%
%     Version 002 26-09-2012 by LNervo
%       Formatting, cleaning, commenting


if ~exist('parameters','var') || isempty(parameters)
    load('parameters.mat');
end

projname = fullfile(parameters.acq.dir, 'absorption_stack.mat');

proj = [];
if exist(projname, 'file')
    check = inputwdefault('Absorption stack already exists - do you want to (re)-create it ? [y/n]', 'n');

    if strcmpi(check,'n')
        proj = load(projname);
    else
        proj = gtAstraPrepareAbsorptionStack(parameters);
    end

else
    proj = gtAstraPrepareAbsorptionStack(parameters);
end

switch parameters.rec.method
    case '3DART'
        abs = gtAstra3D([],[],[],proj);
    case '2DFBP'
        abs = gtAstra_FBP2D(parameters,proj);
    otherwise
        disp('Method for reconstruction not known. Please check parameters file')
        return;
end

end % end of function




