function seg = gtChangeThreshold3D(firstID, lastID, ~, phaseID, varargin)
% GTCHANGETHRESHOLD3D
%     seg = gtChangeThreshold3D(firstID, lastID, ~, phaseID, varargin)
%     ----------------------------------------------------------------
%
%     Reads parameters.mat                     : acq.dir, rec
%     Reads 4_grains/phase_##/grain_****.mat   : vol, shift, id
%     Appends 4_grains/phase_##/grain_****.mat : seg, segbb, threshold, Area
%
%     INPUT:
%       varargin = to modify parameters.rec
%

parameters = [];
load('parameters.mat');

rec = parameters.rec;
rec = parse_pv_pairs(rec, varargin);

if isdeployed
    global GT_DB
    global GT_MATLAB_HOME
    load('workspaceGlobal.mat');
    firstID = str2double(firstID);
    lastID  = str2double(lastID);
    if (ischar(phaseID))
        phaseID = str2double(phaseID);
    else
        warning('OAR:unexpected_behavior', ...
            'We should expect only strings from shell environment')
    end
end
gtDBConnect('graindb.esrf.fr','gtadmin','gtadmin','graintracking');

phaseDir = fullfile(parameters.acq.dir, '4_grains', sprintf('phase_%02d', phaseID));

filetable = sprintf('%s_filetable', parameters.acq.name);
filename = fullfile(parameters.acq.dir, '4_grains', 'sample.mat');

if exist(filename, 'file')
    sample = GtSample.loadFromFile(filename);
else
    disp('Can not find 4_grains/sample.mat !');
    exit;
end


if (~isdeployed), fprintf('Phase %02d: ', phaseID); end
for grainID = firstID : lastID
    if (~isdeployed), fprintf('%04d/(%04d..%04d)', grainID, firstID, lastID); end

    grain_file = fullfile(phaseDir, sprintf('grain_%04d.mat', grainID));
    grain      = load(grain_file, 'vol', 'shift', 'id');
    grain      = gtThresholdGrain3D(grain, rec);
    seg        = grain.seg;
    Area       = grain.Area;
    segbb      = grain.segbb;
    threshold  = grain.threshold;

    if ~isempty(seg)
        %fprintf('\nSaving %s.\n',grain_file)
        %fprintf('                 ')

        save(grain_file, '-append', 'seg', 'segbb', 'threshold', 'Area');
        sample.phases{phaseID}.setBoundingBox(grainID, segbb);
        sample.phases{phaseID}.setThreshold(grainID, threshold);
    else
        fprintf('\n\nWarning! Empty volume in grain %d.\n\n',grainID)
        fprintf('                 ')
    end

    if (~isdeployed), fprintf('\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b'); end
end
if (~isdeployed), fprintf('(%04d..%04d) Done.\n', firstID, lastID); end

disp('now writing to sample.mat')
sample.mergeToFile(filetable, filename, 'sample');

end % end of function

