function output = gtFindSimilarGrains(g1, g2, parameters1, parameters2)
%find similar grains
%given the grain structure generated by sort_grains, containing positions
%and R-vectors, and the parameters files, containing pixel size data...

% Read out data
for ii=1:length(g1)
    map1.R_vec(ii,:) = g1{ii}.R_vector;
    map1.pos(ii,:)   = g1{ii}.center;
end
for ii=1:length(g2)
    map2.R_vec(ii,:) = g2{ii}.R_vector;
    map2.pos(ii,:)   = g2{ii}.center;
end

% Get symmetry operators
tmp = gtCrystGetSymmetryOperators(parameters1.cryst.crystal_system, ...
                                   parameters1.cryst.spacegroup); 
% Keep only the 3x3 operators
if isfield(tmp, 'g3')
    symm = cell2struct({tmp(:).g3}, 'g');
else
    symm = cell2struct({tmp(:).g}, 'g');
end

%try to deal with shifts here.
map1.pos=map1.pos-repmat(mean(map1.pos,1), length(map1.pos), 1);
map2.pos=map2.pos-repmat(mean(map2.pos,1), length(map2.pos), 1);
%scale to pixelsize of map 1
map2.pos=map2.pos*parameters2.acq.pixelsize/parameters1.acq.pixelsize;

%go through grain map 1, looking for matches in grain map 2
output=[];
for ii=1:length(map1.R_vec)

  %calculate misorientations
  misorientation=[];
  for jj=1:length(map2.R_vec)

    g1=Rod2g(map1.R_vec(ii,:));
    g2=Rod2g(map2.R_vec(jj,:));
    %need to search symmetry equivilents for the minimum misorientation
    rot_offset=[];
    for k=1:length(symm)
      g1equiv = symm(k).g*g1;
      netg = inv(g1equiv)*g2;
      rot_offset(k) = acos((trace(netg)-1)/2);
    end

    misorientation(jj)=min(abs(rot_offset));
  end

  %calculate distances
  dif = map2.pos-repmat(map1.pos(ii,:),size(map2.pos,1),1);
  distance = sqrt(sum((dif.^2),2));

  ii
  pos=find(distance<70 & misorientation'<5*pi/180)
  output(ii).possibles=pos;
  output(ii).dif=dif(pos,:);
  output(ii).distance=distance(pos);

  output(ii).misorientations=misorientation(pos);

end

keyboard

