function doneLocaly = gtReconstructGrains(first, last, workingdirectory, phaseID, parameters, varargin)
% GTRECONSTRUCTGRAINS  Launch a series of 3D ART (ASTRA) reconstruction on a GPU machine
%     doneLocaly = gtReconstructGrains(first, last, workingdirectory, phaseID, [parameters], [varargin])
%     --------------------------------------------------------------------------------------------------
%
%     If submitted on a GPU machine it will work locally - otherwise it will
%     submit the job via OAR to a machine with GPU (needed for 3D ASTRA code)
%
%     INPUT:
%       first, last      =
%       workingdirectory =
%       phaseID          =
%       parameters       =
%       varargin         = 'list' [N x 1] <double>  list of grains to be reconstructed
%                                 It is stored in parameters.rec.list
%
%     OUTPUT:
%       doneLocaly       =
%
%
%     FUNCTIONS SUBMITTED TO OAR:
%[oar]- gtReconstructGrains

currentDir = pwd;
cd(workingdirectory);

if isdeployed
    global GT_DB
    global GT_MATLAB_HOME
    load('workspaceGlobal.mat');
    first   = str2double(first);
    last    = str2double(last);
    phaseID = str2double(phaseID);
end

if ~exist('parameters','var') || isempty(parameters)
    load('parameters.mat');
end

rec = parameters.rec;
dir_acq = parameters.acq.dir;

if ~isempty(varargin)
    rec = parse_pv_pairs(rec,varargin);
end

OK = gtCheckGpu();

if ~OK
    disp('ASTRA:no_GPU   gtAstra3D: You should submit this job on a GPU machine ! Exiting...');
end

samplefile = fullfile(parameters.acq.dir, '4_grains', 'sample.mat');
sample = GtSample.loadFromFile(samplefile);

if ~isempty(rec.list)

    if OK
        for ii = 1 : length(rec.list)
           fprintf('%04d/%04d', ii, length(rec.list));
           gtAstraReconstructGrain(ii, phaseID, parameters, sample);
           fprintf('\b\b\b\b\b\b\b\b\b');
        end
    else
        disp('If you provide a list of grains, you need to start this job from a gpu machine, Exiting...');
        return;
    end
else
    if OK
        for ii = first : last
            fprintf('%04d/(%04d..%04d)', ii, first, last);
            gtAstraReconstructGrain(ii, phaseID, parameters, sample);
            fprintf('\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b');
        end
    else
        OAR_make('gtReconstructGrains', first, last, 1, [pwd ' ' num2str(phaseID)], true, 'gpu', 'YES')
    end
end

if (nargout > 0)
    doneLocaly = OK;
end
cd(currentDir)

end % end of function
