function data = gtCubicUnitCell(varargin)

app.centered = true;
app.draw     = true;
app.ratio    = 1;
app.ind      = 0;
app.vertices = false;
app.numbers  = false;
app.patch    = false;
app.axes     = false;
app.view     = [103 20];

app = parse_pv_pairs(app, varargin);

c=1;
a=1/app.ratio;

x0 = [0 1 1 0 0]*a;
y0 = [0 0 1 1 0]*a;
if app.centered
    z0 = repmat(-c/2,1,length(x0));
    z1 = repmat(+c/2,1,length(x0));
else
    z0 = zeros(1,length(x0));
    z1 = repmat(c,1,length(x0));
end
vertices = [[x0;y0;z0],[x0;y0;z1]]';
vertices(1,:)=[];
vertices(5,:)=[];

if app.draw
    figure;
    line(x0,y0,z0);
    line(x0,y0,z1);
    hold on;
    if app.vertices
        plot3(x0,y0,z0,'.k')
        plot3(x0(1),y0(1),z0(1),'.b')
        plot3(x0,y0,z1,'.k')
        plot3(x0(1),y0(1),z1(1),'.b')
    end
    for ii=1:length(x0)
        plot3([x0(ii) x0(ii)],[y0(ii) y0(ii)],[z0(ii) z1(ii)], 'b-', 'LineWidth', 1)
    end
    quiver3(0,0,z0(1),1.1,0,0,0,'k')
    quiver3(0,0,z0(1),0,1.1,0,0,'k')
    quiver3(0,0,z0(1),0,0,1.1,0,'k')
    text(1+0.2,0,z0(1),'a1','Color',[0 0 0])
    text(0,1+0.2,z0(1),'a2','Color',[0 0 0])
    text(0,0,z1(1)+0.2,'a3','Color',[0 0 0])
    if app.numbers
        for ii=1:size(vertices,1)
            text(vertices(ii,1),vertices(ii,2),vertices(ii,3)+0.1,num2str(ii),'Color',[0 0 0])
        end
    end
    view(app.view)
    if app.axes
        % lab system : x y z vectors
        quiver3(-1,0,0,2,0,0,0,'r');
        quiver3(0,-1,0,0,2,0,0,'k');
        quiver3(0,0,-1,0,0,2,0,'b');
        xlabel('x')
        ylabel('y')
        zlabel('z')
    end
end
   
faces_sides = [1 2 6 5; 2 3 7 6; 3 4 8 7; 4 1 5 8];
faces_end   = [5 6 7 8; 1 2 3 4];
hkl         = [1 0 0; 0 1 0; -1 0 0; 0 -1 0;...
               0 0 1; 0 0 -1]';

if app.draw && app.patch
    if app.ind >=1 && app.ind <=4
      patch('Vertices', vertices, 'Faces', faces_sides(app.ind,:), ...
        'FaceVertexCData', repmat([0 0.8 0],length(app.ind),1), 'FaceColor', 'flat');
    elseif app.ind==5 || app.ind==6
      patch('Vertices', vertices, 'Faces', faces_end(app.ind-6,:), ...
        'FaceVertexCData', repmat([0 0.8 0],length(app.ind),1), 'FaceColor', 'flat');
    elseif app.ind==0
      patch('Vertices', vertices, 'Faces', faces_sides, ...
        'FaceVertexCData', repmat([0 0.8 0],4,1), 'FaceColor', 'flat');
      patch('Vertices', vertices, 'Faces', faces_end, ...
        'FaceVertexCData', repmat([0 0.8 0],2,1), 'FaceColor', 'flat');
    end
end

vertices(end+1,:) = [0 0 (z1(1)-z0(1))/3];
vertices(end+1,:) = [0 0 (z1(1)-z0(1))/3*2];

vertices(end+1,:) = [0 0 (z1(1)-z0(1))/4];
vertices(end+1,:) = [0 0 (z1(1)-z0(1))/4*2];
vertices(end+1,:) = [0 0 (z1(1)-z0(1))/4*3];

if app.draw
  axis equal
  set(gca,'Visible','off')
    if app.numbers
        for ii=9:length(vertices)
            text(vertices(ii,1),vertices(ii,2),vertices(ii,3)+0.1,num2str(ii),'Color',[0 0 0])
        end
    end
    if app.vertices
        for ii=9:length(vertices)
            plot3(vertices(ii,1),vertices(ii,2),vertices(ii,3),'.k')
        end
    end
end
if nargout == 1
    data.vertices = vertices;
    data.faces_sides = faces_sides;
    data.faces_end = faces_end;
    data.hkl = hkl;
    data.hf  = gcf;
end

end % end of function
