

function maps=gtMosaicityCmaps(dct_vol)

% function to read average omega extension per grain data from the
% database, and make colormaps.  
% warning - need be careful about the max grainid that is actually present in
% the volume/image!  For this reason pass in the volume/image, and make maps
% considering the max id that is present.
% now saved in /matlabDCT/6_rendering/gtMosaicityCmaps.m
%
% make volume and radius cmaps, based on the volume passed in
%
% data(grainid, :)=[Nblobs, mean(extent) med(extent) mean(ext-extent)
% med(ext-extent) volume radius]


load('parameters.mat');
gtDBConnect

[difspotid, extension, extextension]=mym(sprintf('select difspotid, endimage-startimage, extendimage-extstartimage from %sdifspot',parameters.acq.name));

maxgrain=max(dct_vol(:));

data=[];

for g=1:maxgrain

    [listA, listB, eta, theta]=mym(sprintf('select difaid, difbid, eta, theta from %sspotpairs where grainid=%d',parameters.acq.name,g));
    
    list=[listA; listB];
    eta=[eta; eta+180];
    theta=[theta; theta];
    tmp=[];
    exttmp=[];
    tan2eta=tand(eta).^2;
    sin2th=sind(theta).^2;
    ny=sqrt(tan2eta.*(1-sin2th)./(1+tan2eta));
    ny(find(isnan(ny)))=1; % if eta=90, cor->NaN
    
    
    
    for i=1:length(list)
        
        tmp(i)=extension(find(difspotid==list(i)));
        % sin(eta) correction for the eta angle...  is this reasonable?
        % yes, but better is
       tmp(i)=tmp(i)*ny(i);
        
        exttmp(i)=extextension(find(difspotid==list(i)));
        exttmp(i)=exttmp(i)*ny(i);
    end

    data(g, 1)=length(list);
    data(g, 2)=mean(tmp);
    data(g, 3)=median(tmp);
    data(g, 4)=mean(exttmp);
    data(g, 5)=median(exttmp);
end

% define maps
maps.meanmap=zeros(maxgrain+1, 3);
maps.medmap=zeros(maxgrain+1, 3);
maps.extmeanmap=zeros(maxgrain+1, 3);
maps.extmedmap=zeros(maxgrain+1, 3);

% add data
maps.meanmap(2:end, :)=[data(:,2), data(:,2), data(:,2)];
maps.medmap(2:end, :)=[data(:,3), data(:,3), data(:,3)];
maps.extmeanmap(2:end, :)=[data(:,4), data(:,4), data(:,4)];
maps.extmedmap(2:end, :)=[data(:,5), data(:,5), data(:,5)];

% normalise
maps.meanmap=maps.meanmap/max(maps.meanmap(:));
maps.medmap=maps.medmap/max(maps.medmap(:));
maps.extmeanmap=maps.extmeanmap/max(maps.extmeanmap(:));
maps.extmedmap=maps.extmedmap/max(maps.extmedmap(:));

% add a colour for grains with no data
maps.meanmap(find(isnan(maps.meanmap(:,1))), :)=repmat([.2 0 0], length(find(isnan(maps.meanmap(:,1)))), 1);
maps.medmap(find(isnan(maps.medmap(:,1))), :)=repmat([.2 0 0], length(find(isnan(maps.medmap(:,1)))), 1);
maps.extmeanmap(find(isnan(maps.extmeanmap(:,1))), :)=repmat([.2 0 0], length(find(isnan(maps.extmeanmap(:,1)))), 1);
maps.extmedmap(find(isnan(maps.extmedmap(:,1))), :)=repmat([.2 0 0], length(find(isnan(maps.extmedmap(:,1)))), 1);


% define volume and radius maps
maps.rmap=zeros(maxgrain+1, 3);
maps.volmap=zeros(maxgrain+1, 3);

for g=1:maxgrain
data(g, 6)=sum(dct_vol(:)==g);
end

data(:,7)=((3*data(:,6))/(4*pi)).^(1/3);

maps.volmap(2:end, :)=repmat(data(:,6), 1, 3)/max(data(:,6));
maps.rmap(2:end, :)=repmat(data(:,7), 1, 3)/max(data(:,7));

% add data to the maps structure for future reference
maps.data=data;
maps.data_key='nblobs mean med meanext medext vol rad'


