function [allshkls, allhklinds, mult]  = gtCrystSignedHKLs(hkl,spacegroup)
% GTCRYSTSIGNEDHKLS  Gives a complete list of signed hkl planes, by
%     applying symmetry operators of the specified spacegroup to the input
%     list of plane families.
%     Should be revised for at least other than cubic lattices. Use of 
%     'lattice_system' and 'crystal_system' instead of spacegroups should
%     be considered.
%
%     [allshkls, allhklinds, mult] = gtCrystSignedHKLs(hkl,spacegroup)
%     ----------------------------------------------------------------
%
%     INPUT:
%       hkl        = plane families (one in a row)
%                    nx3,class double for cubic lattices 
%                    nx4,class double for hexagonal lattices
%       spacegroup = space group
%
%     OUTPUT:
%       allshkls   = complete list of signed hkl planes
%                    (including Friedel pairs)
%       allhklinds = indices in allshkls according to input hkl 
%       mult       = multiplicity of hkl families
%

% Get symmetry operators
symm = gtCrystGetSymmetryOperators([], spacegroup);

allshkls   = [];
allhklinds = [];

% Loop through input hkl types
for ii = 1:size(hkl,1)

    shkls = [];

    % Apply all symmmetry operators to the hkl type to get signed hkl-s
    for jj = 1:length(symm)
		shkls(2*jj-1,:) =  hkl(ii,:)*symm(jj).g;
		shkls(2*jj,:)   = -shkls(2*jj-1,:);  % Friedel pair of previous one
    end

	% Remove duplicates and add to the complete list
    newshkls = unique(shkls, 'rows');
	allshkls = [allshkls; newshkls];
    
    mult(ii,1)  = size(newshkls,1);
    
    allhklinds = [allhklinds; repmat(ii,size(newshkls,1),1)];

end


end % end of function

