classdef GtAstraBenchmarks < GtBenchmarks
    methods (Access = public, Static)
        function benchmark3Dset(numIters, sirtDetectImages)
            if (~exist('numIters', 'var'))
                numIters = 20;
            end
            if (~exist('sirtDetectImages', 'var'))
                sirtDetectImages = rand(1e2, 2e2, 3e2);
            end
            proj = [];
            proj.stack = sirtDetectImages;
            proj.num_cols = size(sirtDetectImages, 1);
            proj.num_rows = size(sirtDetectImages, 3);
            proj.geom = ones(size(sirtDetectImages, 2), 12);
            proj_geom = astra_create_proj_geom('parallel3d_vec', proj.num_rows, proj.num_cols, proj.geom);

            bytes = GtBenchmarks.getSizeVariable(sirtDetectImages);
            GtBenchmarks.printHeader('Set Mex Data 3D', bytes)
            fprintf(' - Doing %d iterations: ', numIters)

            tic();
            for ii = 1:numIters
                proj_id  = astra_mex_data3d('create', '-proj3d', proj_geom, proj.stack);
                astra_mex_data3d('delete', proj_id);
            end
            GtBenchmarks.printResult('astra_mex_data3d(''create'', ''-proj3d'')', toc()/numIters, bytes);

            % Let's assume 'get' is correct!
            proj_id  = astra_mex_data3d('create', '-proj3d', proj_geom, proj.stack);
            copied = astra_mex_data3d('get', proj_id);
            astra_mex_data3d('delete', proj_id);

            GtBenchmarks.verifyError(sirtDetectImages, copied);
        end

        function benchmark3Dget(numIters, sirtDetectImages)
            if (~exist('numIters', 'var'))
                numIters = 20;
            end
            if (~exist('sirtDetectImages', 'var'))
                sirtDetectImages = rand(1e2, 2e2, 3e2);
            end
            proj = [];
            proj.stack = sirtDetectImages;
            proj.num_cols = size(sirtDetectImages, 1);
            proj.num_rows = size(sirtDetectImages, 3);
            proj.geom = ones(size(sirtDetectImages, 2), 12);
            proj_geom = astra_create_proj_geom('parallel3d_vec', proj.num_rows, proj.num_cols, proj.geom);

            bytes = GtBenchmarks.getSizeVariable(sirtDetectImages);
            GtBenchmarks.printHeader('Get Mex Data 3D', bytes)
            fprintf(' - Doing %d iterations: ', numIters)
            proj_id  = astra_mex_data3d('create', '-proj3d', proj_geom, proj.stack);

            tic();
            for ii = 1:numIters
                proj = astra_mex_data3d('get', proj_id);
            end
            astra_mex_data3d('delete', proj_id);
            GtBenchmarks.printResult('astra_mex_data3d(''get'', proj_id)', toc()/numIters, bytes);
        end

        function allBenchmarks()
            imgs = rand(5e2, 5e2, 5e2);

            GtAstraBenchmarks.benchmark3Dset(5, imgs)
            GtAstraBenchmarks.benchmark3Dget(5, imgs)
        end
    end
end
