classdef GtSample < handle
    properties
        phases = { };

        volumeFile = '';

        absVolFile = '';
        
        fileTable = '';
    end

    methods (Access = public)
        function obj = GtSample(phases_num, volume_file, absvol_file, file_table)
        % GTSAMPLE/GTSAMPLE Constructor

            if (~exist('phases_num', 'var'))
                phases_num = 1;
            end
            if (exist('volume_file', 'var'))
                obj.volumeFile = volume_file;
            end
            if (exist('absvol_file', 'var'))
                obj.absVolFile = absvol_file;
            end
            obj.phases = cell(1, phases_num);
            for ii = 1: phases_num
                obj.phases{ii} = GtPhase();
            end
            if (exist('file_table', 'var'))
                obj.fileTable = file_table;
            end    
        end

        function updateConflicts(obj, other)
        % GTSAMPLE/UPDATECONFLICTS  Copies the content of grains_merge into the
        % sample.mat
            
            for phaseNum = 1:length(other.phases)
                for grainNum = 1:length(other.phases{phaseNum}.summary)
                    obj.mergeSummaryField(other, phaseNum, grainNum, 'totspots', []);
                    obj.mergeSummaryField(other, phaseNum, grainNum, 'numgrain', []);
                    obj.mergeSummaryField(other, phaseNum, grainNum, 'delete', false);
                    obj.mergeSummaryField(other, phaseNum, grainNum, 'flag', 0);
                    % merge idspot
                    if ~isempty(other.phases{phaseNum}.summary{grainNum}.idspot)
                        obj.phases{phaseNum}.summary{grainNum}.idspot = ...
                            other.phases{phaseNum}.summary{grainNum}.idspot;
                    end
                    % merge idconflict
                    if ~isempty(other.phases{phaseNum}.summary{grainNum}.idconflict)
                        obj.phases{phaseNum}.summary{grainNum}.idconflict = ...
                            other.phases{phaseNum}.summary{grainNum}.idconflict;
                    end
                    % merge difspotID
                    if ~isempty(other.phases{phaseNum}.summary{grainNum}.difspotID)
                        obj.phases{phaseNum}.summary{grainNum}.difspotID = ...
                            other.phases{phaseNum}.summary{grainNum}.difspotID;
                    end
                end
                for grainNum = 1:length(other.phases{phaseNum}.conflicts)
                    n_conflicts = obj.phases{phaseNum}.summary{grainNum}.numgrain;
                    if (n_conflicts ~= other.phases{phaseNum}.summary{grainNum}.numgrain)
                        error('GT_SAMPLE:wrong_size', ...
                              'The merging of summary field ''numgrain'' has an error.');
                    end

                    if ~isempty(n_conflicts)
                        % re-initialise the number of conflicts based on
                        % numgrain
                        obj.phases{phaseNum}.conflicts{grainNum} = repmat(GtConflict(),1,n_conflicts);

                        % merge difspots
                        for conflictid = 1:n_conflicts
                            obj.phases{phaseNum}.conflicts{grainNum}(conflictid).difspots = ...
                                other.phases{phaseNum}.conflicts{grainNum}(conflictid).difspots;
                        end

                        obj.mergeConflictsField(other, phaseNum, grainNum, 'maxnum', false);
                        obj.mergeConflictsField(other, phaseNum, grainNum, 'merge', []);
                        obj.mergeConflictsField(other, phaseNum, grainNum, 'allequals', false);
                    end
                end

                % Merge hasConflicts
                obj.mergePhaseField(other, phaseNum, 'hasConflicts', false);
                % Merge nofConflicts
                obj.mergePhaseField(other, phaseNum, 'nofConflicts', 0);
            end
        end
        
        function merge(obj, other)
        % GTSAMPLE/MERGE Merges an other instance of this class to the current
        % object.
        % It will overwrite just the values from the other class that are not
        % the default values: So be careful to really know what you are doing
        % when you merge two instances.
        % Moreover, it assumes complete coherence between the two objects
        % (number of grains in the phases, and number of phases)

            obj.checkObjectCoherence(other);

            for phaseNum = 1:length(other.phases)
                for grainNum = 1:length(other.phases{phaseNum}.grains)
                    obj.mergeGrainField(other, phaseNum, grainNum, 'threshold', 0);
                    if ~isempty(other.phases{phaseNum}.grains{grainNum}.selectedDiffspots)
                        obj.phases{phaseNum}.grains{grainNum}.selectedDiffspots = ...
                            other.phases{phaseNum}.grains{grainNum}.selectedDiffspots;
                    end
                end
                % Merge selectedGrains
                obj.mergePhaseField(other, phaseNum, 'selectedGrains', true);
                % Merge completeness
                obj.mergePhaseField(other, phaseNum, 'completeness', 1);
                % Merge center
                obj.mergePhaseField(other, phaseNum, 'center', 0);
                % Merge R_vector
                obj.mergePhaseField(other, phaseNum, 'R_vector', 0);
                % Merge boundingBox
                obj.mergePhaseField(other, phaseNum, 'boundingBox', 0);
                % Merge bboxExtremes
                obj.mergePhaseField(other, phaseNum, 'bboxExtremes', 0);
            end
            
            obj.updateConflicts(other);
        end

        function mergeToFile(obj, fileTable, fileName, fieldName)
        % GTSAMPLE/MERGETOFILE This merges the current object into an existing
        % object, which is loaded from a file.
        %
        % It is synchronized using a GtLock. So it is quite safe in a parallel
        % environment, but still is limited by the intrinsic limitations of the
        % GtLock class

            if (~exist('fieldName', 'var'))
                fieldName = 'sample';
            end
         
            lock = GtLockDB(fileTable, fileName);
            lock.acquire();

            sample = load(fileName, fieldName);
            sample = sample.(fieldName);
            sample.merge(obj);

            save(fileName, 'sample', '-v7.3');

            lock.release();
        end

        function saveToFile(obj, fileName)
        % GTSAMPLE/SAVETOFILE This saves the current object into a new file. If
        % the file already exists, it is overwritten.

            sample = obj;
            save(fileName, 'sample', '-v7.3');
        end

        function grainIDs = getGrainsWithDifspotsNumLessThan(obj, value)
        % GTSAMPLE/GETGRAINSWITHDIFSPOTSNUMLESSTHAN Queries the GtPhase
        % instances to find the grains which have fewer diffspots than specified

            grainIDs = {};
            for phaseID = 1:length(obj.phases)
                grainIDs{phaseID} = ...
                    obj.phases{phaseID}.getGrainsWithDifspotsNumLessThan(value);
            end
        end

        function grainIDs = getGrainsWithCompletenessLessThan(obj, value)
        % GTSAMPLE/GETGRAINSWITHCOMPLETENESSLESSTHAN Queries the GtPhase
        % instances to find the grains which have a lower completeness than the
        % value

            grainIDs = {};
            for phaseID = 1:length(obj.phases)
                grainIDs{phaseID} = ...
                    obj.phases{phaseID}.getGrainsWithCompletenessLessThan(value);
            end
        end
    end

    methods (Access = private)
        function checkObjectCoherence(obj, other)
        % GTSAMPLE/CHECKOBJECTCOHERENCE It checks complete coherence between the
        % two objects (number of grains in the phases, and number of phases)

            if (~isa(other, 'GtSample'))
                error('GT_SAMPLE:wrong_argument', ...
                      'It is possible to merge just instances of the GtSample class');
            elseif (length(other.phases) ~= length(obj.phases))
                error('GT_SAMPLE:wrong_argument', ...
                      'Samples should have the same number of phases');
            else
                for numPhase = 1:length(other.phases)
                    if (length(other.phases{numPhase}.grains) ...
                            ~= length(obj.phases{numPhase}.grains))
                        error('GT_SAMPLE:wrong_argument', ...
                              'Phases should have the same number of grains');
                    end
                    if (length(other.phases{numPhase}.summary) ...
                            ~= length(obj.phases{numPhase}.summary))
                        error('GT_SAMPLE:wrong_argument', ...
                              'Phases should have the same number of summary');
                    end
                    if (length(other.phases{numPhase}.conflicts) ...
                            ~= length(obj.phases{numPhase}.conflicts))
                        error('GT_SAMPLE:wrong_argument', ...
                              'Phases should have the same number of conflicts');
                    end 
                end
            end
        end

        function mergePhaseField(obj, other, phaseNum, field, defaultValue)
        % GTSAMPLE/MERGEPHASEFIELD

            localField = obj.phases{phaseNum}.(field);
            otherField = other.phases{phaseNum}.(field);
            if (any(size(localField) == 1))
                indexes = find(otherField ~= defaultValue);
                localField(indexes) = otherField(indexes);
            else
                indexes = find(sum(abs(otherField), 2) ~= defaultValue);
                localField(indexes, :) = otherField(indexes, :);
            end
            obj.phases{phaseNum}.(field) = localField;
        end

        function mergeGrainField(obj, other, phaseNum, grainNum, field, defaultValue)
        % GTSAMPLE/MERGEGRAINFIELD
            if ~isempty(defaultValue) && (other.phases{phaseNum}.grains{grainNum}.(field) ~= defaultValue)
                obj.phases{phaseNum}.grains{grainNum}.(field) = ...
                                            other.phases{phaseNum}.grains{grainNum}.(field);
            elseif isempty(defaultValue)
                obj.phases{phaseNum}.grains{grainNum}.(field) = ...
                                            other.phases{phaseNum}.grains{grainNum}.(field);
            end
        end

        function mergeSummaryField(obj, other, phaseNum, grainNum, field, defaultValue)
        % GTSAMPLE/MERGESUMMARYFIELD
            if ~isempty(defaultValue) && (other.phases{phaseNum}.summary{grainNum}.(field) ~= defaultValue)
                    obj.phases{phaseNum}.summary{grainNum}.(field) = ...
                                                other.phases{phaseNum}.summary{grainNum}.(field);
            elseif isempty(defaultValue)
                obj.phases{phaseNum}.summary{grainNum}.(field) = ...
                                            other.phases{phaseNum}.summary{grainNum}.(field);
            end
        end

        function mergeConflictsField(obj, other, phaseNum, grainNum, field, defaultValue)
        % GTSAMPLE/MERGECONFLICTSFIELD
            if (length(other.phases{phaseNum}.conflicts{grainNum}) ~= other.phases{phaseNum}.summary{grainNum}.numgrain)
                error('GT_Sample:wrong_size', ...
                      'The value of summary{grainNum}.numgrain does not correspond to the length of conflicts{grainNum}.');
            end
            for conflictid = 1:length(other.phases{phaseNum}.conflicts{grainNum})
                if ~isempty(defaultValue) && (other.phases{phaseNum}.conflicts{grainNum}(conflictid).(field) ~= defaultValue)
                    obj.phases{phaseNum}.conflicts{grainNum}(conflictid).(field) = ...
                                                other.phases{phaseNum}.conflicts{grainNum}(conflictid).(field);
                elseif isempty(defaultValue)
                    obj.phases{phaseNum}.conflicts{grainNum}(conflictid).(field) = ...
                                                other.phases{phaseNum}.conflicts{grainNum}(conflictid).(field);
                end
            end
        end
    end

    methods (Static, Access = public)
        function sample = loadFromLockedFile(fileTable, fileName, fieldName)
        % GTSAMPLE/LOADFROMFILE Synchronized loading from a file

            if (~exist('fieldName', 'var'))
                fieldName = 'sample';
            end

            lock = GtLockDB(fileTable, fileName);
            lock.acquire();

            sample = load(fileName, fieldName);
            sample = sample.(fieldName);

            lock.release();
        end
        
        function sample = loadFromFile(fileName, fieldName)
        % GTSAMPLE/LOADFROMFILE Synchronized loading from a file

            if (~exist('fieldName', 'var'))
                fieldName = 'sample';
            end
            
            sample = load(fileName, fieldName);
            sample = sample.(fieldName);

        end
        
        function sample = convertToSample(grains_merge)
        % GTSAMPLE/CONVERTTOSAMPLE  Convert grains_merge object into sa GtSample object
                        
            % create an empty GtSample object
            sample = GtSample(length(grains_merge));

            for phaseNum = 1:length(grains_merge)
                sample.phases{phaseNum}.summary      = grains_merge{phaseNum}.summary;
                sample.phases{phaseNum}.conflicts    = grains_merge{phaseNum}.conflicts;
                sample.phases{phaseNum}.hasConflicts = grains_merge{phaseNum}.hasConflicts;
                sample.phases{phaseNum}.nofConflicts = grains_merge{phaseNum}.nofConflicts;
            end
        end
        
    end
end
