function jacobs_ray3d = jacobs_ray3d(im_size, p1_x, p1_y, p1_z, p2_x, p2_y, p2_z, voxel_size)
%JACOBS_RAY3D   Ray tracing through voxel grid
%   J = JACOBS_RAY3D( im_size, p1_x, p1_y, p1_z, p2_x, p2_y, p2_z,
%   voxel_size) returns a sparse vector with entries in positions
%   corresponding to weighted intersections of a line, with the grid. The
%   positions in the vector corresponds to a 3d matlab array reshaped to a
%   vector using RESHAPE( ARRAY, [], 1)
%
%   im_size is the number of voxels along one dimension of the 3d array.
%   p1 and p2 contain coordinates of the starting and end point,
%   respectively.
%   relative a coordinate system with its origin in the centre of the voxel
%   grid.
%   voxel size is the size (length units) of each voxel in the grid.
%
%   the weights are fractions of the total line length
%
%   to calculate radiographs, calculate the inner product of J with a
%   vector containing the volume elements. ( DOT(J, X_VEC), where X_VEC =
%   RESHAPE(X, [], 1)  )


% jacobs_ray3d
% Calculates intersection lengths of a line with a voxel grid
% Implementation of algorithm described by F. Jacobs et.al.
% 
% F. Jacobs, E. Sundermann, B. De Sutter, M. Christiaens and I. Lemahieu, ["A Fast
% Algorithm to Calculate the Exact Radiological Path through a Pixel or Voxel
% Space"
% Journal of Computing and Information Technology - CIT 6 1998, 1, pp 89-94]
% 
% Written by David Szotten 2005-2006
% D.Szotten@student.manchester.ac.uk
% 
% Copyright (c) The University of Manchester 2006

jacobs_ray3d = jacobs_ray3d_c( im_size, p1_x, p1_y, p1_z, p2_x, p2_y, p2_z, voxel_size );

end
