function answer = inputwdefault(question, default, is_numeric)
% INPUTWDEFAULT  User input function from the command line with default value
% ---------------------------------------------------------------------------
%
%   INPUT:
%     question  = <string>  Message printed to tell the user what to enter
%     default   = <string>  Default value for input
%
%   OPTIONAL INPUT:
%     isnumeric = <any>     Specify that the input is a numeric one
%
%   OUTPUT:
%     answer    = <string>  User input (take the default one if empty)
%                 <double>  Returns double if numeric

    if ~ischar(default)
        gtError('inputwdefault:wrong_argument', ['default argument should be a string, not a ' class(default)]);
    end

    if (~exist('is_numeric', 'var'))
        is_numeric = false;
    end

    questionAlign = 30;
    % conform to 80x24 terminals
    needNewLine = (max(length(question), questionAlign) + 6 + length(default)) > 80;

    if (needNewLine)
        questionFormat = ['%-' num2str(questionAlign) 's :\n[%s]\n'];
    else
        questionFormat = ['%-' num2str(questionAlign) 's : [%s] '];
    end
     
    answer = input(sprintf(questionFormat, question, default), 's');

    if isempty(answer)
        answer = default;
    end
    if (is_numeric)
        answer = eval(answer);
    end
end % end of function
