function labgeo = gtGeoLabDefaultParameters(acq)
% GTGEOLABDEFAULTPARAMETERS
%     labgeo = gtGeoLabDefaultParameters(acq)
%     ---------------------------------------
%     Use of acq.dist, acq.pixelsize, acq.xdet, acq.ydet,
%     acq.no_direct_beam
% 

labgeo = [];

if acq.no_direct_beam
    % Assume vertical setup; detector is above sample pointing downwards (-Z)
    disp('No direct beam case. Assuming vetical detector position to generate default setup parameters.')
    labgeo.rotdir    = [0 -1 0];
    labgeo.detrefpos = [0 0 acq.dist];
    labgeo.detdiru   = [0 1 0];
    labgeo.detdirv   = [1 0 0];

    % Should guess sample envelope
    labgeo.samenvtop = [];
    labgeo.samenvbot = [];
    labgeo.samenvrad = [];

else % inline detector - suppose it on x-axis
    labgeo.rotdir    = [0 0 -1];
    labgeo.detrefpos = [acq.dist 0 0];
    labgeo.detdiru   = [0 1 0];
    labgeo.detdirv   = [0 0 -1];

    % Should take sample envelope from sample bbox (parameters.acq.bb) if
    % exists, otherwise in gtPreprocessing
    if isfield(acq,'bb') && ~isempty(acq.bb)
        labgeo.samenvtop = (acq.bb(4)/2) * acq.pixelsize * 1.1;
        labgeo.samenvbot = -labgeo.samenvtop;
        labgeo.samenvrad = (acq.bb(3)/2) * acq.pixelsize * 1.1;
    else
        labgeo.samenvtop = [];
        labgeo.samenvbot = [];
        labgeo.samenvrad = [];
    end
end

if strcmpi(acq.rotation_direction,'clockwise') && strcmpi(acq.rotation_axis,'horizontal')
    labgeo.rotdir = abs(labgeo.rotdir);
end

labgeo.pixelsizeu = acq.pixelsize;
labgeo.pixelsizev = acq.pixelsize;
labgeo.detsizeu   = acq.xdet; % number of pixels along the u direction
labgeo.detsizev   = acq.ydet; % number of pixels along the v direction

% Beam direction, rot. axis position and detector properties
labgeo.beamdir = [1 0 0];
labgeo.rotpos  = [0 0 0];
labgeo.detrefu = 1024.5;
labgeo.detrefv = 1024.5;
% labgeo.detnorm is redundant, and can be calculated any time; so better not to have
% it here.
labgeo.detnorm = cross(labgeo.detdiru,labgeo.detdirv);


% Coordinate axes definition and Lab unit (for records only)
labgeo.reflabX = 'Along the beam direction.';
labgeo.reflabY = 'Right-handed from Y=cross(Z,X).';
labgeo.reflabZ = 'Along rotation axis. Positive away from sample stage.';
labgeo.labunit = 'mm';
        
% Compute detector origin from the reference position
% labgeo.detorig is redundant, and can be calculated any time; so better not to have
% it here.
labgeo.detorig = labgeo.detrefpos - ...
                     labgeo.detrefu*labgeo.detdiru*labgeo.pixelsizeu - ...
                     labgeo.detrefv*labgeo.detdirv*labgeo.pixelsizev;
                        
end % end of function
