function info = gtVersion()
% GTVERSION  Gives matlabDCT version used with svn information
%     -------------------------------------------------------------------------
%     svnInfo = gtVersion 
%
%     INPUT:
%
%     OUTPUT:
%       info  = <struct> SVN infos about the DCT code currently used
%
%     Version 001 22-08-2012 by YGuilhem

% Get GT_MATLAB_HOME (which is set in initialise_gt) variable and display it
global GT_MATLAB_HOME;
disp(['You are using DCT code from directory: ' GT_MATLAB_HOME]);

% Store LANG env variable and set it as C
lang = getenv('LANG');
if ~isempty(lang)
    setenv('LANG','C');
end

% Guess svn info related to DCT_DIR
[status, result] = system(['svn info --non-interactive ' GT_MATLAB_HOME]);

% Set back LANG env variable
if ~isempty(lang)
    setenv('LANG',lang);
end

if status
    disp('Warning: Couldn''t get svn info!');
else
    % Initalise values
    svnInfo = struct();
    % Parse output from svn info 
    svnStruct = regexp(result, '(?<svnPar>[\w ]+): (?<svnValue>\S+)', 'names');
    if ~isempty(svnStruct)
        for i=1:length(svnStruct)
            svnField = strrep(svnStruct(i).svnPar, ' ', '_');
            svnInfo.(svnField) = svnStruct(i).svnValue;
        end
        disp(['SVN repository URL: ' svnInfo.URL]);
        disp(['SVN revision number: ' svnInfo.Revision]);
    else
        disp('Warning: Couldn''t parse svn info!');
    end
    if nargout
        info = svnInfo;
    end
end % end of function
