function r = gtMathsEuler2Rod(euler)
% GTMATHSEULER2ROD  Convert Euler angles (in degrees) to Rodrigues vectors.
%                   These follow Bunge convention (ZXZ) [phi1, phi, phi2].
%
%     r = gtMathsEuler2Rod(euler)
%     -------------------------------------------------------------------------
%
%     INPUT:
%       euler = <double>  M Euler angles triplets, as row vectors (Mx3 matrix).
%
%     OUTPUT:
%       r     = <double>  M Rodrigues vectors, as row vectors (Mx3 matrix).
%
%     Version 002 17-10-2012 by YGuilhem
%       Vectorize function to process quickly lots of Euler angles
%
%     Version 001 15-06-2012 by YGuilhem

% Check size of r row vectors
if size(euler, 2) ~= 3
    gtError('Rodrigues:wrong_vector_size', ... 
        'Given matrix size is not Mx3!');
end

% Create Euler angles vectors
phi1 = euler(:, 1);
phi  = euler(:, 2);
phi2 = euler(:, 3);

% Compute intermediate values a & b
a = (phi1 - phi2)/2;
b = (phi1 + phi2)/2;

% Compute intermediate cosine and tangent to speed up
cosb   = cosd(b);
tanphi = tand(phi/2);

% Compute Rodrigues vector components
r = [ tanphi .* cosd(a)./cosb , ...
      tanphi .* sind(a)./cosb , ...
      tand(b)                 ];

end % end of function
