function isUpToDate = gtCheckFunctionUpToDate(funcName, outputBinary, verbose)
% GTCHECKFUNCTIONUPTODATE Checks if a compiled function is up to date.

    if (~exist('verbose', 'var'))
        verbose = true;
    end

    srcFileInfo = dir(funcName);
    if (isempty(srcFileInfo))
        error('CHECK:wrong_function_path', ...
              'The given function path: "%s" doesn''t exist', funcName);
    end

    binFileInfo = dir(outputBinary);
    if (~isempty(binFileInfo))
        if (srcFileInfo(1).datenum > binFileInfo(1).datenum)
            if (verbose), fprintf(' + Binary is outdated.\n'); end
            isUpToDate = false;
        else
            deps = gtGetFunctionDeps({funcName}, {}, 'matlab_(\d*)(.?)/toolbox');
            depsToRebuild = gtCheckFunctionsTimestamp(deps, binFileInfo(1).datenum);
            isUpToDate = isempty(depsToRebuild);
            if (~isUpToDate && verbose)
                cellfun(@(x)fprintf(' + "%s" was modified after it.\n', x), ...
                        depsToRebuild);
            end
        end
    else
        if (verbose), fprintf(' + Binary doesn''t exist.\n'); end
        isUpToDate = false;
    end
end
