function compiled_fine = gt_mcc(myfunctionname)
% gt_mcc.m Compiles an executable and puts it in the right place
    if (isempty(whos('global', 'GT_MATLAB_HOME')))
        error('COMPILE:no_such_variable', ...
              ['GT_MATLAB_HOME variable doesn''t exist in global workspace, '...
               'your environment is not sane, and you need to either ' ...
               're-initialise or re-run matlab.'])
    end
    global GT_MATLAB_HOME
    try
        v = ver('compiler');
        mcc_vers = textscan(v.Version, '%s','delimiter','.');
        mcc_vers_minor = str2double(mcc_vers{1}{2});
        mcc_vers_major = str2double(mcc_vers{1}{1});
        compiled_fine = true; % In case of error, we will re modify it
    catch mexc
        gtPrintException(mexc, 'Error: Is the Matlab Compiler installed?')
        compiled_fine = false;
        return
    end

    cpu = getenv('CPU');
    path_for_binaries = fullfile(GT_MATLAB_HOME, 'bin', 'compiled',  cpu);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Modify the M name if necessary
    if ~strcmp(myfunctionname(end-1:end), '.m')
        myfunctionname = [myfunctionname '.m'];
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % check the code is visible at the moment
    if ~exist(myfunctionname,'file')
        disp('Cannot find your function - is it in the path?')
        compiled_fine = false;
        return
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Adding Global Workspace
    globalVars = whos('global');
    eval(['global' sprintf(' %s', globalVars.('name'))]);
    if (isempty(whos('global', 'GT_DB')))
        error('COMPILE:no_such_variable', ...
              ['GT_DB variable doesn''t exist in global workspace, '...
               'your environment is not sane, and you need to either ' ...
               're-initialise or re-run matlab.'])
    end
    save('workspaceGlobal.mat', 'GT_DB', 'GT_MATLAB_HOME');

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % startup the compiler
    disp('Starting to compile - this may take a few minutes...')
    disp('- Removing previously compiled code')
    filemask = [path_for_binaries '/' myfunctionname(1:end-2) '*'];
    delete(filemask);

    fprintf('- Placing result in %s\n', path_for_binaries);
    try
        mcc('-m', myfunctionname, '-d', path_for_binaries, '-a', 'workspaceGlobal.mat');
    catch mexc
        if gtCheckExceptionType(mexc, 'mcc_err_checkout_failed')
            disp('Could not get a compiler license.')
            disp('Surf to http://compweb/public/nice/matlab_licence.php')
            disp('and call the person with the compiler license to see if you could use it!')
        else
            gtPrintException(mexc);
        end
        compiled_fine = false;
        return
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Now extract the archive (only necessary the first time)
    % extracting the CTF file not necessary with R2008 and beyond (R2011b has compiler_version = 4.16)
    if ( mcc_vers_major < 4 || (mcc_vers_major == 4 && mcc_vers_minor < 8))
        ctfname = [path_for_binaries '/' myfunctionname(1:end-2) '.ctf'];
        fprintf('  Compiler version %d.%d.\n', mcc_vers_major, mcc_vers_minor)
        fprintf('- Now attempting to extract the archive...\n\n')
        cmd = sprintf('%s/toolbox/compiler/deploy/%s/extractCTF %s', matlabroot, ...
                        getenv('ARCH'), ctfname);
        try
            [status, result] = unix(cmd);
        catch mexc
            gtPrintException(mexc, 'Extraction of archive did not work')
        end

        if status ~= 0
            disp('There was a problem with compilation');

            disp(result)
            compiled_fine = false;
        end
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Clean the folder
    delete('workspaceGlobal.mat');

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % And let the user know everything is finished
    fprintf('Documentation on http://wikiserv.esrf.fr/id19\n')
    fprintf('PLEASE RESTART MATLAB TO FREE THE COMPILER FOR SOMEONE ELSE!\n')
end
