function script_location = make_oar_matlab(pathdir, tmpdir, tmpname, oarpars)
    if (isempty(whos('global', 'GT_MATLAB_HOME')))
        error('COMPILE:no_such_variable', ...
              ['GT_MATLAB_HOME variable doesn''t exist in global workspace, '...
               'your environment is not sane, and you need to either ' ...
               're-initialise or re-run matlab.'])
    end
    global GT_MATLAB_HOME

    script_location = fullfile(pathdir, [oarpars.name '-' getenv('USER') '_' num2str(oarpars.resubmit) '.oar']);
    tmp_location    = fullfile(tmpdir, [tmpname '-' getenv('USER') '_' num2str(oarpars.resubmit) '.oar']);

    % matlabroot can be tricky on Macs
    exportPath   = 'export PATH="${PATH}:';
    exportLibary = 'export LD_LIBRARY_PATH="${LD_LIBRARY_PATH}:';

    script_content = {'#!/bin/bash', ...
        ['#OAR -l {type = ''default''}/core='  num2str(oarpars.core) '/nodes=' num2str(oarpars.node) ...
            '/cpu=' num2str(oarpars.cpu) ',walltime=' oarpars.walltime], ...
        ['#OAR -p (host like ''' oarpars.host '%'') AND (desktop_computing = ''NO'')'] ...
        ['#OAR -p (gpu = ''' oarpars.gpu ''') AND (mem>' num2str(oarpars.mem) ')'], ...
        ['#OAR -O ' oarpars.stdout], ...
        ['#OAR -E ' oarpars.stderr], ...
        ['#OAR --checkpoint ' num2str(oarpars.checkpoint)], ...
        ['#OAR --signal ' num2str(oarpars.signal)], ...
        ['#OAR --type ' oarpars.type], ...
        ['#OAR --array-param-file ' fullfile(pathdir, [oarpars.name '-' getenv('USER') '_' num2str(oarpars.resubmit) '.params'])], ...
        ['#OAR --name ' oarpars.name], ...
        '#OAR --project graintracking', ...
        '', ...
        ['source ' fullfile(GT_MATLAB_HOME, 'setup_gt_env')], ...
        ... % To make compiled functions visible
        [exportPath fullfile(GT_MATLAB_HOME, 'bin', 'compiled', getenv('CPU')) '"'], ...
        ... % On linux systems it is surely required, but on windows the path could be different
        [exportLibary fullfile(matlabroot, 'runtime', 'glnxa64') '"'], ...
        [exportLibary fullfile(matlabroot, 'bin', 'glnxa64') '"'], ...
        [exportLibary fullfile(matlabroot, 'sys', 'os', 'glnxa64') '"'], ...
        [exportLibary fullfile(matlabroot, 'sys', 'java', 'jre', 'glnxa64', 'jre', 'lib', 'amd64', 'server') '"'], ...
        '', ...
        '"$@"' };
    script_content(2, :) = {sprintf('\n')};

    fid = fopen(script_location, 'w');
    fprintf(fid, '%s\n', [script_content{:}]);
    fclose(fid);

    fidtmp = fopen(tmp_location, 'w');
    fprintf(fidtmp, '%s\n', [script_content{:}]);
    fclose(fidtmp);
end
