function [updateFile,emptyFile] = gtAddMatFile(existingFile,addedFile,update,missing,addall,empty)
% GTADDMATFILE  Merges, adds or updates fields between .mat files
%     [updateFile,emptyFile] = gtAddMatFile(existingFile,addedFile,update,missing,addall,empty)
%     -----------------------------------------------------------------------------------------
%
%     INPUT:
%       existingFile = to be updated/modified <struct>
%       addedfile    = to be added to the 'existingFile' <struct>
%       update       = flag to update each of the existing fields in 'existingFile' by double-checking {false}
%       missing      = flag to add missing fields in 'existingFile' from 'newFile' {false}
%       addall       = flag to add all the fields of 'addedFile' to 'existingFile' without a double-check {false}
%       empty        = flag to check empty fields {false}
%
%     OUTPUT:
%       updateFile   = the resulting structure
%       emptyFile    = list of empty fields
%
%     Version 004 25/04/2021 by LNervo
%       Add flag 'empty'
%
%     Version 003 24/04/2012 by LNervo
%       Check functionality
%


debug = false;
out = GtConditionalOutput(debug);

if ~exist('update','var') || isempty(update)
    update=false;
end
if ~exist('missing','var') || isempty(missing)
    missing=false;
end
if ~exist('addall','var') || isempty(addall)
    addall=false;
end
if ~exist('empty','var') || isempty(empty)
    empty=false;
end

names      = fieldnames(addedFile); % from the structure to be added
existnames = fieldnames(existingFile); % from the existing structure to be modified
        
for i=1:length(names) 
    if ~isfield(existingFile,names{i}) && ~isfield(existingFile,lower(names{i})) % is not a field of 'existingFile'
        out.odisp(['>>> ' names{i} ' is not a field... It will be SKIPPED... <<<'])
        if missing && ~addall && ~update
            variable=names{i};
            out.odisp(['--> ' variable ' <--'])
            check=inputwdefault('Do you want to add this field? [y/n]','n');
            if strcmpi(check,'y')
                out.odisp(['added field: ' names{i}])       
                existingFile.(names{i})=addedFile.(names{i});
            end
        elseif missing || addall
            out.odisp(['added field: ' names{i}])       
            existingFile.(names{i})=addedFile.(names{i});
        end
    end
    if isfield(existingFile,lower(names{i})) && ~isfield(existingFile,names{i}) %is a field but lowercase of 'existingFile'
        variable=lower(names{i});
        if ~update
            oldvalue=existingFile.(variable);
            newvalue=addedFile.(names{i});
            if ~ischar(oldvalue)
                oldvalue=num2str(oldvalue);
            end
            if ~ischar(newvalue)
                newvalue=num2str(newvalue);
            end
            out.odisp(['--> ' variable ' <--'])
            out.odisp('old: ')
            out.odisp(oldvalue)
            out.odisp('new: ')
            out.odisp(newvalue)
            check=inputwdefault('Are you sure to replace it with the new value? [y/n]','n');
        else
            out.odisp(['--> ' names{i} ' <--'])
            check=inputwdefault('Are those the same thing? [y/n]','n');
            if strcmpi(check,'y')
                out.odisp(['updated field: ' variable ' with field: ' names{i}])
                existingFile.(variable)=addedFile.(names{i});
            end
        end
    end
    if isfield(existingFile,names{i}) % is a field of 'existingFile'
        if ~update
            variable=names{i};
            oldvalue=existingFile.(names{i});
            newvalue=addedFile.(names{i});
            if ~ischar(oldvalue) && ~iscell(oldvalue) && ~islogical(oldvalue) && ~isstruct(oldvalue)
                oldvalue=num2str(oldvalue);
            end
            if ~ischar(newvalue) && ~iscell(newvalue) && ~islogical(newvalue) && ~isstruct(newvalue)
                newvalue=num2str(newvalue);
            end
            if ~isequal(newvalue,oldvalue)
                out.odisp(['--> ' variable ' <--'])
                out.odisp('old: ')
                out.odisp(oldvalue)
                out.odisp('new: ')
                out.odisp(newvalue)
                check=inputwdefault('Do you want to replace it with the new value? [y/n]','n');
            
                if strcmpi(check,'y')
                    out.odisp(['replaced field: ' names{i}])
                    existingFile.(names{i})=addedFile.(names{i});
                end
            end

        else
            out.odisp(['updated field: ' names{i}])
            existingFile.(names{i})=addedFile.(names{i});  
        end
    end
end % end for i

list_empty=[];
if empty % check empty fields
    for j=1:length(existnames)
        if isempty(existingFile.(existnames{j}))
            out.odisp(['^^^ ' existnames{j} ' is empty ^^^'])
            list_empty.(existnames{j})=existingFile.(existnames{j});
        end
    end
    emptyFile=list_empty;
    out.odisp('Empty fields:')
    out.odisp(emptyFile)
end

updateFile=existingFile;

end % end of function
    
