'''
Created on Apr 25, 2012

@author: vigano
'''

import os
import datetime
import shutil

from xml_dct_io import DCTCheck, DCTConf

class ConfUpdater(object):

    def __init__(self, base_dir = os.getcwd()):
        self.base_dir = base_dir

    def _getNewFilename(self, filepath):
        timestamp = datetime.datetime.fromtimestamp(os.path.getmtime(filepath))
        pieces = os.path.splitext(filepath)
        return (pieces[0] + "-" + timestamp.strftime("%Y-%m-%d-%H-%M") + pieces[1])

    def backup(self, filename):
        filepath = os.path.join(self.base_dir, filename)
        if not os.path.exists(filepath):
            raise ValueError("No such file %s" % filename)
        newFilePath = self._getNewFilename(filepath)
        os.rename(filepath, newFilePath)
        print("Made backup copy of file: '%s' -> '%s'" % (filepath, newFilePath))

    def copy(self, oldfilename, newfilename):
        oldfilepath = os.path.join(self.base_dir, oldfilename)
        newfilepath = os.path.join(self.base_dir, newfilename)
        shutil.copy2(oldfilepath, newfilepath)

    def safelyInstallNewFile(self, oldfilename, newfilename):
        try:
            self.backup(newfilename)
        except:
            print("Creating new file: '%s'" % newfilename)
        self.copy(oldfilename, newfilename)

    def updateXMLConfFile(self):
        print "Update conf.xml file with current DCT configuration..."
        conf = DCTConf()
        conf.setRootDir(os.getenv('DCT_DIR'))
        conf.save()

if __name__ == '__main__':
    upd = ConfUpdater()
    DCTCheck().checkCwdWithDCTDir()
    confexamplefile = os.path.join("zUtil_Conf", "conf.example.xml")
    upd.safelyInstallNewFile(confexamplefile, "conf.xml")
    upd.updateXMLConfFile()
    setupexamplefile = os.path.join("zUtil_Conf", "setup_gt_env.example")
    upd.safelyInstallNewFile(setupexamplefile, "setup_gt_env")
