'''
Created on Dec 27, 2011

@author: vigano
'''

import os

try:
    import lxml.etree as ET
except ImportError as ex:
    print("Couldn't import lxml. Trying with standard distribution.")
    try:
        import xml.etree.ElementTree as ET
    except ImportError as ex1:
        print(ex1)
        raise ex1

class DCTOutput(object):

    def printError(self, args):
        print("\n\033[31;1mError: %s\033[39;0m\n" % "".join(args))

class DCTXMLBase(object):

    def __init__(self, xmlFile):
        self.xmlFile = xmlFile
        self.tree =  ET.parse(xmlFile)

    def save(self, newName = None):
        if newName is not None:
            self.xmlFile = newName
        self.tree.write(self.xmlFile)

class DCTCheck(object):

    def checkCwdWithDCTDir(self, dctdir = os.getenv('DCT_DIR')):
        print "Checking if current directory matches with DCT_DIR environment variable...",
        indir = os.getcwd()
        try:
            os.chdir(dctdir)
            testdir = os.getcwd()
        except:
            raise EnvironmentError("DCT_DIR environment variable (%s) points to inexistent directory!" % dctdir)
        os.chdir(indir)
        if indir == testdir:
            print "OK"
        else:
            raise EnvironmentError("Current working directory does not match with DCT_DIR environment variable!\n%s != %s" % (indir, dctdir))

class DCTConf(DCTXMLBase):

    def __init__(self):
        DCTXMLBase.__init__(self, "conf.xml")

    def getVersion(self):
        return self.tree.findtext("version", "0")

    def getMatlabCommand(self):
        return self.tree.findtext("matlab_command", "matlab")

    def getMexPath(self):
        return self.tree.findtext("mex_path", "mex")

    def getRootDir(self):
        return self.tree.findtext("root_dir")

    def setRootDir(self, newRoot):
        self.tree.find("root_dir").text = newRoot

    def getMexFiles(self):
        return MexConf(self.tree.find("mex_files"))

class MexConf(object):

    def __init__(self, tree):
        self.tree = tree

    def isExcluded(self, testFile):
        for exclude in self.tree.findall("exclude_list/path"):
            if exclude.text in testFile:
                return True
        else:
            return False

    def getFileProperties(self, filePath):
        for fileEntry in self.tree.findall("file"):
            if fileEntry.findtext("path") in filePath:
                output = { }

                output["includes"] = []
                for include in fileEntry.findall("includes/path"):
                    output["includes"].append(include.text)

                output["lib_paths"] = []
                for lib_path in fileEntry.findall("libraries/path"):
                    output["lib_paths"].append(lib_path.text)

                output["libs"] = []
                for lib in fileEntry.findall("libraries/lib"):
                    output["libs"].append(lib.text)

                output["defines"] = []
                for lib in fileEntry.findall("preprocessor/define"):
                    output["defines"].append(lib.text)

                return output
        else:
            return None

